from pwnlib.constants.constant import Constant

__ARM_EABI__ = Constant('__ARM_EABI__',1)
__KERNEL__ = Constant('__KERNEL__',1)
_ARM_SYSCALL_H = Constant('_ARM_SYSCALL_H',1)
__NR_OABI_SYSCALL_BASE = Constant('__NR_OABI_SYSCALL_BASE',0x900000)
__NR_SYSCALL_BASE = Constant('__NR_SYSCALL_BASE',0)
__NR_restart_syscall = Constant('__NR_restart_syscall',(0+  0))
__NR_exit = Constant('__NR_exit',(0+  1))
__NR_fork = Constant('__NR_fork',(0+  2))
__NR_read = Constant('__NR_read',(0+  3))
__NR_write = Constant('__NR_write',(0+  4))
__NR_open = Constant('__NR_open',(0+  5))
__NR_close = Constant('__NR_close',(0+  6))
__NR_creat = Constant('__NR_creat',(0+  8))
__NR_link = Constant('__NR_link',(0+  9))
__NR_unlink = Constant('__NR_unlink',(0+ 10))
__NR_execve = Constant('__NR_execve',(0+ 11))
__NR_chdir = Constant('__NR_chdir',(0+ 12))
__NR_time = Constant('__NR_time',(0+ 13))
__NR_mknod = Constant('__NR_mknod',(0+ 14))
__NR_chmod = Constant('__NR_chmod',(0+ 15))
__NR_lchown = Constant('__NR_lchown',(0+ 16))
__NR_lseek = Constant('__NR_lseek',(0+ 19))
__NR_getpid = Constant('__NR_getpid',(0+ 20))
__NR_mount = Constant('__NR_mount',(0+ 21))
__NR_umount = Constant('__NR_umount',(0+ 22))
__NR_setuid = Constant('__NR_setuid',(0+ 23))
__NR_getuid = Constant('__NR_getuid',(0+ 24))
__NR_stime = Constant('__NR_stime',(0+ 25))
__NR_ptrace = Constant('__NR_ptrace',(0+ 26))
__NR_alarm = Constant('__NR_alarm',(0+ 27))
__NR_pause = Constant('__NR_pause',(0+ 29))
__NR_utime = Constant('__NR_utime',(0+ 30))
__NR_access = Constant('__NR_access',(0+ 33))
__NR_nice = Constant('__NR_nice',(0+ 34))
__NR_sync = Constant('__NR_sync',(0+ 36))
__NR_kill = Constant('__NR_kill',(0+ 37))
__NR_rename = Constant('__NR_rename',(0+ 38))
__NR_mkdir = Constant('__NR_mkdir',(0+ 39))
__NR_rmdir = Constant('__NR_rmdir',(0+ 40))
__NR_dup = Constant('__NR_dup',(0+ 41))
__NR_pipe = Constant('__NR_pipe',(0+ 42))
__NR_times = Constant('__NR_times',(0+ 43))
__NR_brk = Constant('__NR_brk',(0+ 45))
__NR_setgid = Constant('__NR_setgid',(0+ 46))
__NR_getgid = Constant('__NR_getgid',(0+ 47))
__NR_geteuid = Constant('__NR_geteuid',(0+ 49))
__NR_getegid = Constant('__NR_getegid',(0+ 50))
__NR_acct = Constant('__NR_acct',(0+ 51))
__NR_umount2 = Constant('__NR_umount2',(0+ 52))
__NR_ioctl = Constant('__NR_ioctl',(0+ 54))
__NR_fcntl = Constant('__NR_fcntl',(0+ 55))
__NR_setpgid = Constant('__NR_setpgid',(0+ 57))
__NR_umask = Constant('__NR_umask',(0+ 60))
__NR_chroot = Constant('__NR_chroot',(0+ 61))
__NR_ustat = Constant('__NR_ustat',(0+ 62))
__NR_dup2 = Constant('__NR_dup2',(0+ 63))
__NR_getppid = Constant('__NR_getppid',(0+ 64))
__NR_getpgrp = Constant('__NR_getpgrp',(0+ 65))
__NR_setsid = Constant('__NR_setsid',(0+ 66))
__NR_sigaction = Constant('__NR_sigaction',(0+ 67))
__NR_setreuid = Constant('__NR_setreuid',(0+ 70))
__NR_setregid = Constant('__NR_setregid',(0+ 71))
__NR_sigsuspend = Constant('__NR_sigsuspend',(0+ 72))
__NR_sigpending = Constant('__NR_sigpending',(0+ 73))
__NR_sethostname = Constant('__NR_sethostname',(0+ 74))
__NR_setrlimit = Constant('__NR_setrlimit',(0+ 75))
__NR_getrlimit = Constant('__NR_getrlimit',(0+ 76))
__NR_getrusage = Constant('__NR_getrusage',(0+ 77))
__NR_gettimeofday = Constant('__NR_gettimeofday',(0+ 78))
__NR_settimeofday = Constant('__NR_settimeofday',(0+ 79))
__NR_getgroups = Constant('__NR_getgroups',(0+ 80))
__NR_setgroups = Constant('__NR_setgroups',(0+ 81))
__NR_select = Constant('__NR_select',(0+ 82))
__NR_symlink = Constant('__NR_symlink',(0+ 83))
__NR_readlink = Constant('__NR_readlink',(0+ 85))
__NR_uselib = Constant('__NR_uselib',(0+ 86))
__NR_swapon = Constant('__NR_swapon',(0+ 87))
__NR_reboot = Constant('__NR_reboot',(0+ 88))
__NR_readdir = Constant('__NR_readdir',(0+ 89))
__NR_mmap = Constant('__NR_mmap',(0+ 90))
__NR_munmap = Constant('__NR_munmap',(0+ 91))
__NR_truncate = Constant('__NR_truncate',(0+ 92))
__NR_ftruncate = Constant('__NR_ftruncate',(0+ 93))
__NR_fchmod = Constant('__NR_fchmod',(0+ 94))
__NR_fchown = Constant('__NR_fchown',(0+ 95))
__NR_getpriority = Constant('__NR_getpriority',(0+ 96))
__NR_setpriority = Constant('__NR_setpriority',(0+ 97))
__NR_statfs = Constant('__NR_statfs',(0+ 99))
__NR_fstatfs = Constant('__NR_fstatfs',(0+100))
__NR_socketcall = Constant('__NR_socketcall',(0+102))
__NR_syslog = Constant('__NR_syslog',(0+103))
__NR_setitimer = Constant('__NR_setitimer',(0+104))
__NR_getitimer = Constant('__NR_getitimer',(0+105))
__NR_stat = Constant('__NR_stat',(0+106))
__NR_lstat = Constant('__NR_lstat',(0+107))
__NR_fstat = Constant('__NR_fstat',(0+108))
__NR_vhangup = Constant('__NR_vhangup',(0+111))
__NR_syscall = Constant('__NR_syscall',(0+113))
__NR_wait4 = Constant('__NR_wait4',(0+114))
__NR_swapoff = Constant('__NR_swapoff',(0+115))
__NR_sysinfo = Constant('__NR_sysinfo',(0+116))
__NR_ipc = Constant('__NR_ipc',(0+117))
__NR_fsync = Constant('__NR_fsync',(0+118))
__NR_sigreturn = Constant('__NR_sigreturn',(0+119))
__NR_clone = Constant('__NR_clone',(0+120))
__NR_setdomainname = Constant('__NR_setdomainname',(0+121))
__NR_uname = Constant('__NR_uname',(0+122))
__NR_adjtimex = Constant('__NR_adjtimex',(0+124))
__NR_mprotect = Constant('__NR_mprotect',(0+125))
__NR_sigprocmask = Constant('__NR_sigprocmask',(0+126))
__NR_init_module = Constant('__NR_init_module',(0+128))
__NR_delete_module = Constant('__NR_delete_module',(0+129))
__NR_quotactl = Constant('__NR_quotactl',(0+131))
__NR_getpgid = Constant('__NR_getpgid',(0+132))
__NR_fchdir = Constant('__NR_fchdir',(0+133))
__NR_bdflush = Constant('__NR_bdflush',(0+134))
__NR_sysfs = Constant('__NR_sysfs',(0+135))
__NR_personality = Constant('__NR_personality',(0+136))
__NR_setfsuid = Constant('__NR_setfsuid',(0+138))
__NR_setfsgid = Constant('__NR_setfsgid',(0+139))
__NR__llseek = Constant('__NR__llseek',(0+140))
__NR_getdents = Constant('__NR_getdents',(0+141))
__NR__newselect = Constant('__NR__newselect',(0+142))
__NR_flock = Constant('__NR_flock',(0+143))
__NR_msync = Constant('__NR_msync',(0+144))
__NR_readv = Constant('__NR_readv',(0+145))
__NR_writev = Constant('__NR_writev',(0+146))
__NR_getsid = Constant('__NR_getsid',(0+147))
__NR_fdatasync = Constant('__NR_fdatasync',(0+148))
__NR__sysctl = Constant('__NR__sysctl',(0+149))
__NR_mlock = Constant('__NR_mlock',(0+150))
__NR_munlock = Constant('__NR_munlock',(0+151))
__NR_mlockall = Constant('__NR_mlockall',(0+152))
__NR_munlockall = Constant('__NR_munlockall',(0+153))
__NR_sched_setparam = Constant('__NR_sched_setparam',(0+154))
__NR_sched_getparam = Constant('__NR_sched_getparam',(0+155))
__NR_sched_setscheduler = Constant('__NR_sched_setscheduler',(0+156))
__NR_sched_getscheduler = Constant('__NR_sched_getscheduler',(0+157))
__NR_sched_yield = Constant('__NR_sched_yield',(0+158))
__NR_sched_get_priority_max = Constant('__NR_sched_get_priority_max',(0+159))
__NR_sched_get_priority_min = Constant('__NR_sched_get_priority_min',(0+160))
__NR_sched_rr_get_interval = Constant('__NR_sched_rr_get_interval',(0+161))
__NR_nanosleep = Constant('__NR_nanosleep',(0+162))
__NR_mremap = Constant('__NR_mremap',(0+163))
__NR_setresuid = Constant('__NR_setresuid',(0+164))
__NR_getresuid = Constant('__NR_getresuid',(0+165))
__NR_poll = Constant('__NR_poll',(0+168))
__NR_nfsservctl = Constant('__NR_nfsservctl',(0+169))
__NR_setresgid = Constant('__NR_setresgid',(0+170))
__NR_getresgid = Constant('__NR_getresgid',(0+171))
__NR_prctl = Constant('__NR_prctl',(0+172))
__NR_rt_sigreturn = Constant('__NR_rt_sigreturn',(0+173))
__NR_rt_sigaction = Constant('__NR_rt_sigaction',(0+174))
__NR_rt_sigprocmask = Constant('__NR_rt_sigprocmask',(0+175))
__NR_rt_sigpending = Constant('__NR_rt_sigpending',(0+176))
__NR_rt_sigtimedwait = Constant('__NR_rt_sigtimedwait',(0+177))
__NR_rt_sigqueueinfo = Constant('__NR_rt_sigqueueinfo',(0+178))
__NR_rt_sigsuspend = Constant('__NR_rt_sigsuspend',(0+179))
__NR_pread64 = Constant('__NR_pread64',(0+180))
__NR_pwrite64 = Constant('__NR_pwrite64',(0+181))
__NR_chown = Constant('__NR_chown',(0+182))
__NR_getcwd = Constant('__NR_getcwd',(0+183))
__NR_capget = Constant('__NR_capget',(0+184))
__NR_capset = Constant('__NR_capset',(0+185))
__NR_sigaltstack = Constant('__NR_sigaltstack',(0+186))
__NR_sendfile = Constant('__NR_sendfile',(0+187))
__NR_vfork = Constant('__NR_vfork',(0+190))
__NR_ugetrlimit = Constant('__NR_ugetrlimit',(0+191))
__NR_mmap2 = Constant('__NR_mmap2',(0+192))
__NR_truncate64 = Constant('__NR_truncate64',(0+193))
__NR_ftruncate64 = Constant('__NR_ftruncate64',(0+194))
__NR_stat64 = Constant('__NR_stat64',(0+195))
__NR_lstat64 = Constant('__NR_lstat64',(0+196))
__NR_fstat64 = Constant('__NR_fstat64',(0+197))
__NR_lchown32 = Constant('__NR_lchown32',(0+198))
__NR_getuid32 = Constant('__NR_getuid32',(0+199))
__NR_getgid32 = Constant('__NR_getgid32',(0+200))
__NR_geteuid32 = Constant('__NR_geteuid32',(0+201))
__NR_getegid32 = Constant('__NR_getegid32',(0+202))
__NR_setreuid32 = Constant('__NR_setreuid32',(0+203))
__NR_setregid32 = Constant('__NR_setregid32',(0+204))
__NR_getgroups32 = Constant('__NR_getgroups32',(0+205))
__NR_setgroups32 = Constant('__NR_setgroups32',(0+206))
__NR_fchown32 = Constant('__NR_fchown32',(0+207))
__NR_setresuid32 = Constant('__NR_setresuid32',(0+208))
__NR_getresuid32 = Constant('__NR_getresuid32',(0+209))
__NR_setresgid32 = Constant('__NR_setresgid32',(0+210))
__NR_getresgid32 = Constant('__NR_getresgid32',(0+211))
__NR_chown32 = Constant('__NR_chown32',(0+212))
__NR_setuid32 = Constant('__NR_setuid32',(0+213))
__NR_setgid32 = Constant('__NR_setgid32',(0+214))
__NR_setfsuid32 = Constant('__NR_setfsuid32',(0+215))
__NR_setfsgid32 = Constant('__NR_setfsgid32',(0+216))
__NR_getdents64 = Constant('__NR_getdents64',(0+217))
__NR_pivot_root = Constant('__NR_pivot_root',(0+218))
__NR_mincore = Constant('__NR_mincore',(0+219))
__NR_madvise = Constant('__NR_madvise',(0+220))
__NR_fcntl64 = Constant('__NR_fcntl64',(0+221))
__NR_gettid = Constant('__NR_gettid',(0+224))
__NR_readahead = Constant('__NR_readahead',(0+225))
__NR_setxattr = Constant('__NR_setxattr',(0+226))
__NR_lsetxattr = Constant('__NR_lsetxattr',(0+227))
__NR_fsetxattr = Constant('__NR_fsetxattr',(0+228))
__NR_getxattr = Constant('__NR_getxattr',(0+229))
__NR_lgetxattr = Constant('__NR_lgetxattr',(0+230))
__NR_fgetxattr = Constant('__NR_fgetxattr',(0+231))
__NR_listxattr = Constant('__NR_listxattr',(0+232))
__NR_llistxattr = Constant('__NR_llistxattr',(0+233))
__NR_flistxattr = Constant('__NR_flistxattr',(0+234))
__NR_removexattr = Constant('__NR_removexattr',(0+235))
__NR_lremovexattr = Constant('__NR_lremovexattr',(0+236))
__NR_fremovexattr = Constant('__NR_fremovexattr',(0+237))
__NR_tkill = Constant('__NR_tkill',(0+238))
__NR_sendfile64 = Constant('__NR_sendfile64',(0+239))
__NR_futex = Constant('__NR_futex',(0+240))
__NR_sched_setaffinity = Constant('__NR_sched_setaffinity',(0+241))
__NR_sched_getaffinity = Constant('__NR_sched_getaffinity',(0+242))
__NR_io_setup = Constant('__NR_io_setup',(0+243))
__NR_io_destroy = Constant('__NR_io_destroy',(0+244))
__NR_io_getevents = Constant('__NR_io_getevents',(0+245))
__NR_io_submit = Constant('__NR_io_submit',(0+246))
__NR_io_cancel = Constant('__NR_io_cancel',(0+247))
__NR_exit_group = Constant('__NR_exit_group',(0+248))
__NR_lookup_dcookie = Constant('__NR_lookup_dcookie',(0+249))
__NR_epoll_create = Constant('__NR_epoll_create',(0+250))
__NR_epoll_ctl = Constant('__NR_epoll_ctl',(0+251))
__NR_epoll_wait = Constant('__NR_epoll_wait',(0+252))
__NR_remap_file_pages = Constant('__NR_remap_file_pages',(0+253))
__NR_set_tid_address = Constant('__NR_set_tid_address',(0+256))
__NR_timer_create = Constant('__NR_timer_create',(0+257))
__NR_timer_settime = Constant('__NR_timer_settime',(0+258))
__NR_timer_gettime = Constant('__NR_timer_gettime',(0+259))
__NR_timer_getoverrun = Constant('__NR_timer_getoverrun',(0+260))
__NR_timer_delete = Constant('__NR_timer_delete',(0+261))
__NR_clock_settime = Constant('__NR_clock_settime',(0+262))
__NR_clock_gettime = Constant('__NR_clock_gettime',(0+263))
__NR_clock_getres = Constant('__NR_clock_getres',(0+264))
__NR_clock_nanosleep = Constant('__NR_clock_nanosleep',(0+265))
__NR_statfs64 = Constant('__NR_statfs64',(0+266))
__NR_fstatfs64 = Constant('__NR_fstatfs64',(0+267))
__NR_tgkill = Constant('__NR_tgkill',(0+268))
__NR_utimes = Constant('__NR_utimes',(0+269))
__NR_arm_fadvise64_64 = Constant('__NR_arm_fadvise64_64',(0+270))
__NR_pciconfig_iobase = Constant('__NR_pciconfig_iobase',(0+271))
__NR_pciconfig_read = Constant('__NR_pciconfig_read',(0+272))
__NR_pciconfig_write = Constant('__NR_pciconfig_write',(0+273))
__NR_mq_open = Constant('__NR_mq_open',(0+274))
__NR_mq_unlink = Constant('__NR_mq_unlink',(0+275))
__NR_mq_timedsend = Constant('__NR_mq_timedsend',(0+276))
__NR_mq_timedreceive = Constant('__NR_mq_timedreceive',(0+277))
__NR_mq_notify = Constant('__NR_mq_notify',(0+278))
__NR_mq_getsetattr = Constant('__NR_mq_getsetattr',(0+279))
__NR_waitid = Constant('__NR_waitid',(0+280))
__NR_socket = Constant('__NR_socket',(0+281))
__NR_bind = Constant('__NR_bind',(0+282))
__NR_connect = Constant('__NR_connect',(0+283))
__NR_listen = Constant('__NR_listen',(0+284))
__NR_accept = Constant('__NR_accept',(0+285))
__NR_getsockname = Constant('__NR_getsockname',(0+286))
__NR_getpeername = Constant('__NR_getpeername',(0+287))
__NR_socketpair = Constant('__NR_socketpair',(0+288))
__NR_send = Constant('__NR_send',(0+289))
__NR_sendto = Constant('__NR_sendto',(0+290))
__NR_recv = Constant('__NR_recv',(0+291))
__NR_recvfrom = Constant('__NR_recvfrom',(0+292))
__NR_shutdown = Constant('__NR_shutdown',(0+293))
__NR_setsockopt = Constant('__NR_setsockopt',(0+294))
__NR_getsockopt = Constant('__NR_getsockopt',(0+295))
__NR_sendmsg = Constant('__NR_sendmsg',(0+296))
__NR_recvmsg = Constant('__NR_recvmsg',(0+297))
__NR_semop = Constant('__NR_semop',(0+298))
__NR_semget = Constant('__NR_semget',(0+299))
__NR_semctl = Constant('__NR_semctl',(0+300))
__NR_msgsnd = Constant('__NR_msgsnd',(0+301))
__NR_msgrcv = Constant('__NR_msgrcv',(0+302))
__NR_msgget = Constant('__NR_msgget',(0+303))
__NR_msgctl = Constant('__NR_msgctl',(0+304))
__NR_shmat = Constant('__NR_shmat',(0+305))
__NR_shmdt = Constant('__NR_shmdt',(0+306))
__NR_shmget = Constant('__NR_shmget',(0+307))
__NR_shmctl = Constant('__NR_shmctl',(0+308))
__NR_add_key = Constant('__NR_add_key',(0+309))
__NR_request_key = Constant('__NR_request_key',(0+310))
__NR_keyctl = Constant('__NR_keyctl',(0+311))
__NR_semtimedop = Constant('__NR_semtimedop',(0+312))
__NR_vserver = Constant('__NR_vserver',(0+313))
__NR_ioprio_set = Constant('__NR_ioprio_set',(0+314))
__NR_ioprio_get = Constant('__NR_ioprio_get',(0+315))
__NR_inotify_init = Constant('__NR_inotify_init',(0+316))
__NR_inotify_add_watch = Constant('__NR_inotify_add_watch',(0+317))
__NR_inotify_rm_watch = Constant('__NR_inotify_rm_watch',(0+318))
__NR_mbind = Constant('__NR_mbind',(0+319))
__NR_get_mempolicy = Constant('__NR_get_mempolicy',(0+320))
__NR_set_mempolicy = Constant('__NR_set_mempolicy',(0+321))
__NR_openat = Constant('__NR_openat',(0+322))
__NR_mkdirat = Constant('__NR_mkdirat',(0+323))
__NR_mknodat = Constant('__NR_mknodat',(0+324))
__NR_fchownat = Constant('__NR_fchownat',(0+325))
__NR_futimesat = Constant('__NR_futimesat',(0+326))
__NR_fstatat64 = Constant('__NR_fstatat64',(0+327))
__NR_unlinkat = Constant('__NR_unlinkat',(0+328))
__NR_renameat = Constant('__NR_renameat',(0+329))
__NR_linkat = Constant('__NR_linkat',(0+330))
__NR_symlinkat = Constant('__NR_symlinkat',(0+331))
__NR_readlinkat = Constant('__NR_readlinkat',(0+332))
__NR_fchmodat = Constant('__NR_fchmodat',(0+333))
__NR_faccessat = Constant('__NR_faccessat',(0+334))
__NR_unshare = Constant('__NR_unshare',(0+337))
__NR_set_robust_list = Constant('__NR_set_robust_list',(0+338))
__NR_get_robust_list = Constant('__NR_get_robust_list',(0+339))
__NR_splice = Constant('__NR_splice',(0+340))
__NR_arm_sync_file_range = Constant('__NR_arm_sync_file_range',(0+341))
__NR_tee = Constant('__NR_tee',(0+342))
__NR_vmsplice = Constant('__NR_vmsplice',(0+343))
__NR_move_pages = Constant('__NR_move_pages',(0+344))
__NR_getcpu = Constant('__NR_getcpu',(0+345))
__NR_kexec_load = Constant('__NR_kexec_load',(0+347))
__NR_utimensat = Constant('__NR_utimensat',(0+348))
__NR_signalfd = Constant('__NR_signalfd',(0+349))
__NR_timerfd = Constant('__NR_timerfd',(0+350))
__NR_eventfd = Constant('__NR_eventfd',(0+351))
__NR_fallocate = Constant('__NR_fallocate',(0+352))
__NR_timerfd_settime = Constant('__NR_timerfd_settime',(0+353))
__NR_timerfd_gettime = Constant('__NR_timerfd_gettime',(0+354))
__ARM_NR_BASE = Constant('__ARM_NR_BASE',(0+0x0f0000))
__ARM_NR_breakpoint = Constant('__ARM_NR_breakpoint',((0+0x0f0000)+1))
__ARM_NR_cacheflush = Constant('__ARM_NR_cacheflush',((0+0x0f0000)+2))
__ARM_NR_usr26 = Constant('__ARM_NR_usr26',((0+0x0f0000)+3))
__ARM_NR_usr32 = Constant('__ARM_NR_usr32',((0+0x0f0000)+4))
__ARM_NR_set_tls = Constant('__ARM_NR_set_tls',((0+0x0f0000)+5))
__ARGS_exit = Constant('__ARGS_exit',0)
__ARGS_fork = Constant('__ARGS_fork',0)
__ARGS_read = Constant('__ARGS_read',0)
__ARGS_write = Constant('__ARGS_write',0)
__ARGS_open = Constant('__ARGS_open',0)
__ARGS_close = Constant('__ARGS_close',0)
__ARGS_waitpid = Constant('__ARGS_waitpid',0)
__ARGS_creat = Constant('__ARGS_creat',0)
__ARGS_link = Constant('__ARGS_link',0)
__ARGS_unlink = Constant('__ARGS_unlink',0)
__ARGS_execve = Constant('__ARGS_execve',0)
__ARGS_chdir = Constant('__ARGS_chdir',0)
__ARGS_time = Constant('__ARGS_time',0)
__ARGS_mknod = Constant('__ARGS_mknod',0)
__ARGS_chmod = Constant('__ARGS_chmod',0)
__ARGS_lchown = Constant('__ARGS_lchown',0)
__ARGS_break = Constant('__ARGS_break',0)
__ARGS_lseek = Constant('__ARGS_lseek',0)
__ARGS_getpid = Constant('__ARGS_getpid',0)
__ARGS_mount = Constant('__ARGS_mount',1)
__ARGS_umount = Constant('__ARGS_umount',0)
__ARGS_setuid = Constant('__ARGS_setuid',0)
__ARGS_getuid = Constant('__ARGS_getuid',0)
__ARGS_stime = Constant('__ARGS_stime',0)
__ARGS_ptrace = Constant('__ARGS_ptrace',0)
__ARGS_alarm = Constant('__ARGS_alarm',0)
__ARGS_pause = Constant('__ARGS_pause',0)
__ARGS_utime = Constant('__ARGS_utime',0)
__ARGS_stty = Constant('__ARGS_stty',0)
__ARGS_gtty = Constant('__ARGS_gtty',0)
__ARGS_access = Constant('__ARGS_access',0)
__ARGS_nice = Constant('__ARGS_nice',0)
__ARGS_ftime = Constant('__ARGS_ftime',0)
__ARGS_sync = Constant('__ARGS_sync',0)
__ARGS_kill = Constant('__ARGS_kill',0)
__ARGS_rename = Constant('__ARGS_rename',0)
__ARGS_mkdir = Constant('__ARGS_mkdir',0)
__ARGS_rmdir = Constant('__ARGS_rmdir',0)
__ARGS_dup = Constant('__ARGS_dup',0)
__ARGS_pipe = Constant('__ARGS_pipe',0)
__ARGS_times = Constant('__ARGS_times',0)
__ARGS_prof = Constant('__ARGS_prof',0)
__ARGS_brk = Constant('__ARGS_brk',0)
__ARGS_setgid = Constant('__ARGS_setgid',0)
__ARGS_getgid = Constant('__ARGS_getgid',0)
__ARGS_signal = Constant('__ARGS_signal',0)
__ARGS_geteuid = Constant('__ARGS_geteuid',0)
__ARGS_getegid = Constant('__ARGS_getegid',0)
__ARGS_acct = Constant('__ARGS_acct',0)
__ARGS_umount2 = Constant('__ARGS_umount2',0)
__ARGS_lock = Constant('__ARGS_lock',0)
__ARGS_ioctl = Constant('__ARGS_ioctl',0)
__ARGS_fcntl = Constant('__ARGS_fcntl',0)
__ARGS_mpx = Constant('__ARGS_mpx',0)
__ARGS_setpgid = Constant('__ARGS_setpgid',0)
__ARGS_ulimit = Constant('__ARGS_ulimit',0)
__ARGS_umask = Constant('__ARGS_umask',0)
__ARGS_chroot = Constant('__ARGS_chroot',0)
__ARGS_ustat = Constant('__ARGS_ustat',0)
__ARGS_dup2 = Constant('__ARGS_dup2',0)
__ARGS_getppid = Constant('__ARGS_getppid',0)
__ARGS_getpgrp = Constant('__ARGS_getpgrp',0)
__ARGS_setsid = Constant('__ARGS_setsid',0)
__ARGS_sigaction = Constant('__ARGS_sigaction',0)
__ARGS_sgetmask = Constant('__ARGS_sgetmask',0)
__ARGS_ssetmask = Constant('__ARGS_ssetmask',0)
__ARGS_setreuid = Constant('__ARGS_setreuid',0)
__ARGS_setregid = Constant('__ARGS_setregid',0)
__ARGS_sigsuspend = Constant('__ARGS_sigsuspend',0)
__ARGS_sigpending = Constant('__ARGS_sigpending',0)
__ARGS_sethostname = Constant('__ARGS_sethostname',0)
__ARGS_setrlimit = Constant('__ARGS_setrlimit',0)
__ARGS_getrlimit = Constant('__ARGS_getrlimit',0)
__ARGS_getrusage = Constant('__ARGS_getrusage',0)
__ARGS_gettimeofday = Constant('__ARGS_gettimeofday',0)
__ARGS_settimeofday = Constant('__ARGS_settimeofday',0)
__ARGS_getgroups = Constant('__ARGS_getgroups',0)
__ARGS_setgroups = Constant('__ARGS_setgroups',0)
__ARGS_select = Constant('__ARGS_select',0)
__ARGS_symlink = Constant('__ARGS_symlink',0)
__ARGS_readlink = Constant('__ARGS_readlink',0)
__ARGS_uselib = Constant('__ARGS_uselib',0)
__ARGS_swapon = Constant('__ARGS_swapon',0)
__ARGS_reboot = Constant('__ARGS_reboot',0)
__ARGS_readdir = Constant('__ARGS_readdir',0)
__ARGS_mmap = Constant('__ARGS_mmap',0)
__ARGS_munmap = Constant('__ARGS_munmap',0)
__ARGS_truncate = Constant('__ARGS_truncate',0)
__ARGS_ftruncate = Constant('__ARGS_ftruncate',0)
__ARGS_fchmod = Constant('__ARGS_fchmod',0)
__ARGS_fchown = Constant('__ARGS_fchown',0)
__ARGS_getpriority = Constant('__ARGS_getpriority',0)
__ARGS_setpriority = Constant('__ARGS_setpriority',0)
__ARGS_profil = Constant('__ARGS_profil',0)
__ARGS_statfs = Constant('__ARGS_statfs',0)
__ARGS_fstatfs = Constant('__ARGS_fstatfs',0)
__ARGS_ioperm = Constant('__ARGS_ioperm',0)
__ARGS_socketcall = Constant('__ARGS_socketcall',0)
__ARGS_syslog = Constant('__ARGS_syslog',0)
__ARGS_setitimer = Constant('__ARGS_setitimer',0)
__ARGS_getitimer = Constant('__ARGS_getitimer',0)
__ARGS_stat = Constant('__ARGS_stat',0)
__ARGS_lstat = Constant('__ARGS_lstat',0)
__ARGS_fstat = Constant('__ARGS_fstat',0)
__ARGS_vhangup = Constant('__ARGS_vhangup',0)
__ARGS_idle = Constant('__ARGS_idle',0)
__ARGS_syscall = Constant('__ARGS_syscall',0)
__ARGS_wait4 = Constant('__ARGS_wait4',0)
__ARGS_swapoff = Constant('__ARGS_swapoff',0)
__ARGS_sysinfo = Constant('__ARGS_sysinfo',0)
__ARGS_ipc = Constant('__ARGS_ipc',1)
__ARGS_fsync = Constant('__ARGS_fsync',0)
__ARGS_sigreturn = Constant('__ARGS_sigreturn',0)
__ARGS_clone = Constant('__ARGS_clone',0)
__ARGS_setdomainname = Constant('__ARGS_setdomainname',0)
__ARGS_uname = Constant('__ARGS_uname',0)
__ARGS_modify_ldt = Constant('__ARGS_modify_ldt',0)
__ARGS_adjtimex = Constant('__ARGS_adjtimex',0)
__ARGS_mprotect = Constant('__ARGS_mprotect',0)
__ARGS_sigprocmask = Constant('__ARGS_sigprocmask',0)
__ARGS_create_module = Constant('__ARGS_create_module',0)
__ARGS_init_module = Constant('__ARGS_init_module',0)
__ARGS_delete_module = Constant('__ARGS_delete_module',0)
__ARGS_get_kernel_syms = Constant('__ARGS_get_kernel_syms',0)
__ARGS_quotactl = Constant('__ARGS_quotactl',0)
__ARGS_getpgid = Constant('__ARGS_getpgid',0)
__ARGS_fchdir = Constant('__ARGS_fchdir',0)
__ARGS_bdflush = Constant('__ARGS_bdflush',0)
__ARGS_sysfs = Constant('__ARGS_sysfs',0)
__ARGS_personality = Constant('__ARGS_personality',0)
__ARGS_afs_syscall = Constant('__ARGS_afs_syscall',0)
__ARGS_setfsuid = Constant('__ARGS_setfsuid',0)
__ARGS_setfsgid = Constant('__ARGS_setfsgid',0)
__ARGS__llseek = Constant('__ARGS__llseek',1)
__ARGS_getdents = Constant('__ARGS_getdents',0)
__ARGS__newselect = Constant('__ARGS__newselect',1)
__ARGS_flock = Constant('__ARGS_flock',0)
__ARGS_msync = Constant('__ARGS_msync',0)
__ARGS_readv = Constant('__ARGS_readv',0)
__ARGS_writev = Constant('__ARGS_writev',0)
__ARGS_getsid = Constant('__ARGS_getsid',0)
__ARGS_fdatasync = Constant('__ARGS_fdatasync',0)
__ARGS__sysctl = Constant('__ARGS__sysctl',0)
__ARGS_mlock = Constant('__ARGS_mlock',0)
__ARGS_munlock = Constant('__ARGS_munlock',0)
__ARGS_mlockall = Constant('__ARGS_mlockall',0)
__ARGS_munlockall = Constant('__ARGS_munlockall',0)
__ARGS_sched_setparam = Constant('__ARGS_sched_setparam',0)
__ARGS_sched_getparam = Constant('__ARGS_sched_getparam',0)
__ARGS_sched_setscheduler = Constant('__ARGS_sched_setscheduler',0)
__ARGS_sched_getscheduler = Constant('__ARGS_sched_getscheduler',0)
__ARGS_sched_yield = Constant('__ARGS_sched_yield',0)
__ARGS_sched_get_priority_max = Constant('__ARGS_sched_get_priority_max',0)
__ARGS_sched_get_priority_min = Constant('__ARGS_sched_get_priority_min',0)
__ARGS_sched_rr_get_interval = Constant('__ARGS_sched_rr_get_interval',0)
__ARGS_nanosleep = Constant('__ARGS_nanosleep',0)
__ARGS_mremap = Constant('__ARGS_mremap',0)
__ARGS_setresuid = Constant('__ARGS_setresuid',0)
__ARGS_getresuid = Constant('__ARGS_getresuid',0)
__ARGS_vm86 = Constant('__ARGS_vm86',0)
__ARGS_query_module = Constant('__ARGS_query_module',1)
__ARGS_poll = Constant('__ARGS_poll',0)
__ARGS_nfsservctl = Constant('__ARGS_nfsservctl',0)
__ARGS_setresgid = Constant('__ARGS_setresgid',0)
__ARGS_getresgid = Constant('__ARGS_getresgid',0)
__ARGS_prctl = Constant('__ARGS_prctl',1)
__ARGS_rt_sigreturn = Constant('__ARGS_rt_sigreturn',0)
__ARGS_rt_sigaction = Constant('__ARGS_rt_sigaction',0)
__ARGS_rt_sigprocmask = Constant('__ARGS_rt_sigprocmask',0)
__ARGS_rt_sigpending = Constant('__ARGS_rt_sigpending',0)
__ARGS_rt_sigtimedwait = Constant('__ARGS_rt_sigtimedwait',0)
__ARGS_rt_sigqueueinfo = Constant('__ARGS_rt_sigqueueinfo',0)
__ARGS_rt_sigsuspend = Constant('__ARGS_rt_sigsuspend',0)
__ARGS_pread = Constant('__ARGS_pread',0)
__ARGS_pwrite = Constant('__ARGS_pwrite',0)
__ARGS_pread64 = Constant('__ARGS_pread64',0)
__ARGS_pwrite64 = Constant('__ARGS_pwrite64',0)
__ARGS_chown = Constant('__ARGS_chown',0)
__ARGS_getcwd = Constant('__ARGS_getcwd',0)
__ARGS_capget = Constant('__ARGS_capget',0)
__ARGS_capset = Constant('__ARGS_capset',0)
__ARGS_sigaltstack = Constant('__ARGS_sigaltstack',0)
__ARGS_sendfile = Constant('__ARGS_sendfile',0)
__ARGS_vfork = Constant('__ARGS_vfork',0)
__ARGS_ugetrlimit = Constant('__ARGS_ugetrlimit',0)
__ARGS_mmap2 = Constant('__ARGS_mmap2',1)
__ARGS_truncate64 = Constant('__ARGS_truncate64',0)
__ARGS_ftruncate64 = Constant('__ARGS_ftruncate64',0)
__ARGS_stat64 = Constant('__ARGS_stat64',0)
__ARGS_lstat64 = Constant('__ARGS_lstat64',0)
__ARGS_fstat64 = Constant('__ARGS_fstat64',0)
__ARGS_lchown32 = Constant('__ARGS_lchown32',0)
__ARGS_getuid32 = Constant('__ARGS_getuid32',0)
__ARGS_getgid32 = Constant('__ARGS_getgid32',0)
__ARGS_geteuid32 = Constant('__ARGS_geteuid32',0)
__ARGS_getegid32 = Constant('__ARGS_getegid32',0)
__ARGS_setreuid32 = Constant('__ARGS_setreuid32',0)
__ARGS_setregid32 = Constant('__ARGS_setregid32',0)
__ARGS_getgroups32 = Constant('__ARGS_getgroups32',0)
__ARGS_setgroups32 = Constant('__ARGS_setgroups32',0)
__ARGS_fchown32 = Constant('__ARGS_fchown32',0)
__ARGS_setresuid32 = Constant('__ARGS_setresuid32',0)
__ARGS_getresuid32 = Constant('__ARGS_getresuid32',0)
__ARGS_setresgid32 = Constant('__ARGS_setresgid32',0)
__ARGS_getresgid32 = Constant('__ARGS_getresgid32',0)
__ARGS_chown32 = Constant('__ARGS_chown32',0)
__ARGS_setuid32 = Constant('__ARGS_setuid32',0)
__ARGS_setgid32 = Constant('__ARGS_setgid32',0)
__ARGS_setfsuid32 = Constant('__ARGS_setfsuid32',0)
__ARGS_setfsgid32 = Constant('__ARGS_setfsgid32',0)
__ARGS_getdents64 = Constant('__ARGS_getdents64',0)
__ARGS_pivot_root = Constant('__ARGS_pivot_root',0)
__ARGS_mincore = Constant('__ARGS_mincore',0)
__ARGS_madvise = Constant('__ARGS_madvise',0)
__ARGS_fcntl64 = Constant('__ARGS_fcntl64',0)
__ARGS_security = Constant('__ARGS_security',0)
__ARGS_gettid = Constant('__ARGS_gettid',0)
__ARGS_readahead = Constant('__ARGS_readahead',0)
__ARGS_setxattr = Constant('__ARGS_setxattr',1)
__ARGS_lsetxattr = Constant('__ARGS_lsetxattr',1)
__ARGS_fsetxattr = Constant('__ARGS_fsetxattr',1)
__ARGS_getxattr = Constant('__ARGS_getxattr',0)
__ARGS_lgetxattr = Constant('__ARGS_lgetxattr',0)
__ARGS_fgetxattr = Constant('__ARGS_fgetxattr',0)
__ARGS_listxattr = Constant('__ARGS_listxattr',0)
__ARGS_llistxattr = Constant('__ARGS_llistxattr',0)
__ARGS_flistxattr = Constant('__ARGS_flistxattr',0)
__ARGS_removexattr = Constant('__ARGS_removexattr',0)
__ARGS_lremovexattr = Constant('__ARGS_lremovexattr',0)
__ARGS_fremovexattr = Constant('__ARGS_fremovexattr',0)
__ARGS_tkill = Constant('__ARGS_tkill',0)
__ARGS_sendfile64 = Constant('__ARGS_sendfile64',0)
__ARGS_futex = Constant('__ARGS_futex',0)
__ARGS_sched_setaffinity = Constant('__ARGS_sched_setaffinity',0)
__ARGS_sched_getaffinity = Constant('__ARGS_sched_getaffinity',0)
__ARGS_io_setup = Constant('__ARGS_io_setup',0)
__ARGS_io_destroy = Constant('__ARGS_io_destroy',0)
__ARGS_io_getevents = Constant('__ARGS_io_getevents',0)
__ARGS_io_submit = Constant('__ARGS_io_submit',0)
__ARGS_io_cancel = Constant('__ARGS_io_cancel',0)
__ARGS_exit_group = Constant('__ARGS_exit_group',0)
__ARGS_lookup_dcookie = Constant('__ARGS_lookup_dcookie',0)
__ARGS_epoll_create = Constant('__ARGS_epoll_create',0)
__ARGS_epoll_ctl = Constant('__ARGS_epoll_ctl',0)
__ARGS_epoll_wait = Constant('__ARGS_epoll_wait',0)
__ARGS_remap_file_pages = Constant('__ARGS_remap_file_pages',0)
__ARGS_set_thread_area = Constant('__ARGS_set_thread_area',0)
__ARGS_get_thread_area = Constant('__ARGS_get_thread_area',0)
__ARGS_set_tid_address = Constant('__ARGS_set_tid_address',0)
__ARGS_timer_create = Constant('__ARGS_timer_create',0)
__ARGS_timer_settime = Constant('__ARGS_timer_settime',0)
__ARGS_timer_gettime = Constant('__ARGS_timer_gettime',0)
__ARGS_timer_getoverrun = Constant('__ARGS_timer_getoverrun',0)
__ARGS_timer_delete = Constant('__ARGS_timer_delete',0)
__ARGS_clock_settime = Constant('__ARGS_clock_settime',0)
__ARGS_clock_gettime = Constant('__ARGS_clock_gettime',0)
__ARGS_clock_getres = Constant('__ARGS_clock_getres',0)
__ARGS_clock_nanosleep = Constant('__ARGS_clock_nanosleep',0)
__ARGS_statfs64 = Constant('__ARGS_statfs64',0)
__ARGS_fstatfs64 = Constant('__ARGS_fstatfs64',0)
__ARGS_tgkill = Constant('__ARGS_tgkill',0)
__ARGS_utimes = Constant('__ARGS_utimes',0)
__ARGS_arm_fadvise64_64 = Constant('__ARGS_arm_fadvise64_64',1)
__ARGS_fadvise64 = Constant('__ARGS_fadvise64',0)
__ARGS_fadvise64_64 = Constant('__ARGS_fadvise64_64',0)
__ARGS_pciconfig_iobase = Constant('__ARGS_pciconfig_iobase',0)
__ARGS_pciconfig_read = Constant('__ARGS_pciconfig_read',1)
__ARGS_pciconfig_write = Constant('__ARGS_pciconfig_write',1)
__ARGS_mq_open = Constant('__ARGS_mq_open',0)
__ARGS_mq_unlink = Constant('__ARGS_mq_unlink',0)
__ARGS_mq_timedsend = Constant('__ARGS_mq_timedsend',0)
__ARGS_mq_timedreceive = Constant('__ARGS_mq_timedreceive',1)
__ARGS_mq_notify = Constant('__ARGS_mq_notify',0)
__ARGS_mq_getsetattr = Constant('__ARGS_mq_getsetattr',0)
__ARGS_waitid = Constant('__ARGS_waitid',0)
__ARGS_socket = Constant('__ARGS_socket',0)
__ARGS_bind = Constant('__ARGS_bind',0)
__ARGS_connect = Constant('__ARGS_connect',0)
__ARGS_listen = Constant('__ARGS_listen',0)
__ARGS_accept = Constant('__ARGS_accept',0)
__ARGS_getsockname = Constant('__ARGS_getsockname',0)
__ARGS_getpeername = Constant('__ARGS_getpeername',0)
__ARGS_socketpair = Constant('__ARGS_socketpair',0)
__ARGS_send = Constant('__ARGS_send',0)
__ARGS_sendto = Constant('__ARGS_sendto',0)
__ARGS_recv = Constant('__ARGS_recv',0)
__ARGS_recvfrom = Constant('__ARGS_recvfrom',0)
__ARGS_shutdown = Constant('__ARGS_shutdown',0)
__ARGS_setsockopt = Constant('__ARGS_setsockopt',0)
__ARGS_getsockopt = Constant('__ARGS_getsockopt',0)
__ARGS_sendmsg = Constant('__ARGS_sendmsg',0)
__ARGS_recvmsg = Constant('__ARGS_recvmsg',0)
__ARGS_semop = Constant('__ARGS_semop',0)
__ARGS_semget = Constant('__ARGS_semget',0)
__ARGS_semctl = Constant('__ARGS_semctl',0)
__ARGS_msgsnd = Constant('__ARGS_msgsnd',0)
__ARGS_msgrcv = Constant('__ARGS_msgrcv',0)
__ARGS_msgget = Constant('__ARGS_msgget',0)
__ARGS_msgctl = Constant('__ARGS_msgctl',0)
__ARGS_shmat = Constant('__ARGS_shmat',0)
__ARGS_shmdt = Constant('__ARGS_shmdt',0)
__ARGS_shmget = Constant('__ARGS_shmget',0)
__ARGS_shmctl = Constant('__ARGS_shmctl',0)
__ARGS_add_key = Constant('__ARGS_add_key',1)
__ARGS_request_key = Constant('__ARGS_request_key',1)
__ARGS_keyctl = Constant('__ARGS_keyctl',0)
__ARGS_vserver = Constant('__ARGS_vserver',0)
__ARGS_ioprio_set = Constant('__ARGS_ioprio_set',0)
__ARGS_ioprio_get = Constant('__ARGS_ioprio_get',0)
__ARGS_inotify_init = Constant('__ARGS_inotify_init',0)
__ARGS_inotify_add_watch = Constant('__ARGS_inotify_add_watch',0)
__ARGS_inotify_rm_watch = Constant('__ARGS_inotify_rm_watch',0)
__ARGS_mbind = Constant('__ARGS_mbind',1)
__ARGS_get_mempolicy = Constant('__ARGS_get_mempolicy',1)
__ARGS_set_mempolicy = Constant('__ARGS_set_mempolicy',1)
__ARGS_openat = Constant('__ARGS_openat',0)
__ARGS_mkdirat = Constant('__ARGS_mkdirat',0)
__ARGS_mknodat = Constant('__ARGS_mknodat',0)
__ARGS_fchownat = Constant('__ARGS_fchownat',1)
__ARGS_futimesat = Constant('__ARGS_futimesat',0)
__ARGS_fstatat64 = Constant('__ARGS_fstatat64',0)
__ARGS_unlinkat = Constant('__ARGS_unlinkat',0)
__ARGS_renameat = Constant('__ARGS_renameat',0)
__ARGS_linkat = Constant('__ARGS_linkat',1)
__ARGS_symlinkat = Constant('__ARGS_symlinkat',0)
__ARGS_readlinkat = Constant('__ARGS_readlinkat',0)
__ARGS_fchmodat = Constant('__ARGS_fchmodat',0)
__ARGS_faccessat = Constant('__ARGS_faccessat',0)
__ARGS_unshare = Constant('__ARGS_unshare',0)
__ARGS_set_robust_list = Constant('__ARGS_set_robust_list',0)
__ARGS_get_robust_list = Constant('__ARGS_get_robust_list',0)
__ARGS_splice = Constant('__ARGS_splice',1)
__ARGS_arm_sync_file_range = Constant('__ARGS_arm_sync_file_range',0)
__ARGS_sync_file_range2 = Constant('__ARGS_sync_file_range2',0)
__ARGS_tee = Constant('__ARGS_tee',0)
__ARGS_vmsplice = Constant('__ARGS_vmsplice',0)
__ARGS_move_pages = Constant('__ARGS_move_pages',1)
__ARGS_getcpu = Constant('__ARGS_getcpu',0)
__ARGS_kexec_load = Constant('__ARGS_kexec_load',0)
__ARGS_utimensat = Constant('__ARGS_utimensat',0)
__ARGS_signalfd = Constant('__ARGS_signalfd',0)
__ARGS_timerfd = Constant('__ARGS_timerfd',0)
__ARGS_eventfd = Constant('__ARGS_eventfd',0)
__ARGS_fallocate = Constant('__ARGS_fallocate',0)
__ARGS_timerfd_settime = Constant('__ARGS_timerfd_settime',0)
__ARGS_timerfd_gettime = Constant('__ARGS_timerfd_gettime',0)
MAP_32BIT = Constant('MAP_32BIT',0x40)
INADDR_ANY = Constant('INADDR_ANY',0)
INADDR_BROADCAST = Constant('INADDR_BROADCAST',0xffffffff)
INADDR_NONE = Constant('INADDR_NONE',0xffffffff)
INADDR_LOOPBACK = Constant('INADDR_LOOPBACK',0x7f000001)
EPERM = Constant('EPERM',1)
ENOENT = Constant('ENOENT',2)
ESRCH = Constant('ESRCH',3)
EINTR = Constant('EINTR',4)
EIO = Constant('EIO',5)
ENXIO = Constant('ENXIO',6)
E2BIG = Constant('E2BIG',7)
ENOEXEC = Constant('ENOEXEC',8)
EBADF = Constant('EBADF',9)
ECHILD = Constant('ECHILD',10)
EAGAIN = Constant('EAGAIN',11)
ENOMEM = Constant('ENOMEM',12)
EACCES = Constant('EACCES',13)
EFAULT = Constant('EFAULT',14)
ENOTBLK = Constant('ENOTBLK',15)
EBUSY = Constant('EBUSY',16)
EEXIST = Constant('EEXIST',17)
EXDEV = Constant('EXDEV',18)
ENODEV = Constant('ENODEV',19)
ENOTDIR = Constant('ENOTDIR',20)
EISDIR = Constant('EISDIR',21)
EINVAL = Constant('EINVAL',22)
ENFILE = Constant('ENFILE',23)
EMFILE = Constant('EMFILE',24)
ENOTTY = Constant('ENOTTY',25)
ETXTBSY = Constant('ETXTBSY',26)
EFBIG = Constant('EFBIG',27)
ENOSPC = Constant('ENOSPC',28)
ESPIPE = Constant('ESPIPE',29)
EROFS = Constant('EROFS',30)
EMLINK = Constant('EMLINK',31)
EPIPE = Constant('EPIPE',32)
EDOM = Constant('EDOM',33)
ERANGE = Constant('ERANGE',34)
EDEADLK = Constant('EDEADLK',35)
ENAMETOOLONG = Constant('ENAMETOOLONG',36)
ENOLCK = Constant('ENOLCK',37)
ENOSYS = Constant('ENOSYS',38)
ENOTEMPTY = Constant('ENOTEMPTY',39)
ELOOP = Constant('ELOOP',40)
EWOULDBLOCK = Constant('EWOULDBLOCK',11)
ENOMSG = Constant('ENOMSG',42)
EIDRM = Constant('EIDRM',43)
ECHRNG = Constant('ECHRNG',44)
EL2NSYNC = Constant('EL2NSYNC',45)
EL3HLT = Constant('EL3HLT',46)
EL3RST = Constant('EL3RST',47)
ELNRNG = Constant('ELNRNG',48)
EUNATCH = Constant('EUNATCH',49)
ENOCSI = Constant('ENOCSI',50)
EL2HLT = Constant('EL2HLT',51)
EBADE = Constant('EBADE',52)
EBADR = Constant('EBADR',53)
EXFULL = Constant('EXFULL',54)
ENOANO = Constant('ENOANO',55)
EBADRQC = Constant('EBADRQC',56)
EBADSLT = Constant('EBADSLT',57)
EDEADLOCK = Constant('EDEADLOCK',35)
EBFONT = Constant('EBFONT',59)
ENOSTR = Constant('ENOSTR',60)
ENODATA = Constant('ENODATA',61)
ETIME = Constant('ETIME',62)
ENOSR = Constant('ENOSR',63)
ENONET = Constant('ENONET',64)
ENOPKG = Constant('ENOPKG',65)
EREMOTE = Constant('EREMOTE',66)
ENOLINK = Constant('ENOLINK',67)
EADV = Constant('EADV',68)
ESRMNT = Constant('ESRMNT',69)
ECOMM = Constant('ECOMM',70)
EPROTO = Constant('EPROTO',71)
EMULTIHOP = Constant('EMULTIHOP',72)
EDOTDOT = Constant('EDOTDOT',73)
EBADMSG = Constant('EBADMSG',74)
EOVERFLOW = Constant('EOVERFLOW',75)
ENOTUNIQ = Constant('ENOTUNIQ',76)
EBADFD = Constant('EBADFD',77)
EREMCHG = Constant('EREMCHG',78)
ELIBACC = Constant('ELIBACC',79)
ELIBBAD = Constant('ELIBBAD',80)
ELIBSCN = Constant('ELIBSCN',81)
ELIBMAX = Constant('ELIBMAX',82)
ELIBEXEC = Constant('ELIBEXEC',83)
EILSEQ = Constant('EILSEQ',84)
ERESTART = Constant('ERESTART',85)
ESTRPIPE = Constant('ESTRPIPE',86)
EUSERS = Constant('EUSERS',87)
ENOTSOCK = Constant('ENOTSOCK',88)
EDESTADDRREQ = Constant('EDESTADDRREQ',89)
EMSGSIZE = Constant('EMSGSIZE',90)
EPROTOTYPE = Constant('EPROTOTYPE',91)
ENOPROTOOPT = Constant('ENOPROTOOPT',92)
EPROTONOSUPPORT = Constant('EPROTONOSUPPORT',93)
ESOCKTNOSUPPORT = Constant('ESOCKTNOSUPPORT',94)
EOPNOTSUPP = Constant('EOPNOTSUPP',95)
ENOTSUP = Constant('ENOTSUP',95)
EPFNOSUPPORT = Constant('EPFNOSUPPORT',96)
EAFNOSUPPORT = Constant('EAFNOSUPPORT',97)
EADDRINUSE = Constant('EADDRINUSE',98)
EADDRNOTAVAIL = Constant('EADDRNOTAVAIL',99)
ENETDOWN = Constant('ENETDOWN',100)
ENETUNREACH = Constant('ENETUNREACH',101)
ENETRESET = Constant('ENETRESET',102)
ECONNABORTED = Constant('ECONNABORTED',103)
ECONNRESET = Constant('ECONNRESET',104)
ENOBUFS = Constant('ENOBUFS',105)
EISCONN = Constant('EISCONN',106)
ENOTCONN = Constant('ENOTCONN',107)
ESHUTDOWN = Constant('ESHUTDOWN',108)
ETOOMANYREFS = Constant('ETOOMANYREFS',109)
ETIMEDOUT = Constant('ETIMEDOUT',110)
ECONNREFUSED = Constant('ECONNREFUSED',111)
EHOSTDOWN = Constant('EHOSTDOWN',112)
EHOSTUNREACH = Constant('EHOSTUNREACH',113)
EALREADY = Constant('EALREADY',114)
EINPROGRESS = Constant('EINPROGRESS',115)
ESTALE = Constant('ESTALE',116)
EUCLEAN = Constant('EUCLEAN',117)
ENOTNAM = Constant('ENOTNAM',118)
ENAVAIL = Constant('ENAVAIL',119)
EISNAM = Constant('EISNAM',120)
EREMOTEIO = Constant('EREMOTEIO',121)
EDQUOT = Constant('EDQUOT',122)
ENOMEDIUM = Constant('ENOMEDIUM',123)
EMEDIUMTYPE = Constant('EMEDIUMTYPE',124)
ECANCELED = Constant('ECANCELED',125)
ENOKEY = Constant('ENOKEY',126)
EKEYEXPIRED = Constant('EKEYEXPIRED',127)
EKEYREVOKED = Constant('EKEYREVOKED',128)
EKEYREJECTED = Constant('EKEYREJECTED',129)
__SYS_NERR = Constant('__SYS_NERR',((129) + 1))
__LITTLE_ENDIAN = Constant('__LITTLE_ENDIAN',1234)
__BIG_ENDIAN = Constant('__BIG_ENDIAN',4321)
__BYTE_ORDER = Constant('__BYTE_ORDER',1234)
__FLOAT_WORD_ORDER = Constant('__FLOAT_WORD_ORDER',1234)
LITTLE_ENDIAN = Constant('LITTLE_ENDIAN',1234)
BIG_ENDIAN = Constant('BIG_ENDIAN',4321)
BYTE_ORDER = Constant('BYTE_ORDER',1234)
__WORDSIZE = Constant('__WORDSIZE',32)
__FSUID_H = Constant('__FSUID_H',1)
NSIG = Constant('NSIG',32)
_NSIG = Constant('_NSIG',64)
SIGHUP = Constant('SIGHUP',1)
SIGINT = Constant('SIGINT',2)
SIGQUIT = Constant('SIGQUIT',3)
SIGILL = Constant('SIGILL',4)
SIGTRAP = Constant('SIGTRAP',5)
SIGABRT = Constant('SIGABRT',6)
SIGIOT = Constant('SIGIOT',6)
SIGFPE = Constant('SIGFPE',8)
SIGKILL = Constant('SIGKILL',9)
SIGSEGV = Constant('SIGSEGV',11)
SIGPIPE = Constant('SIGPIPE',13)
SIGALRM = Constant('SIGALRM',14)
SIGTERM = Constant('SIGTERM',15)
SIGUNUSED = Constant('SIGUNUSED',31)
SIGBUS = Constant('SIGBUS',7)
SIGUSR1 = Constant('SIGUSR1',10)
SIGUSR2 = Constant('SIGUSR2',12)
SIGSTKFLT = Constant('SIGSTKFLT',16)
SIGCHLD = Constant('SIGCHLD',17)
SIGCONT = Constant('SIGCONT',18)
SIGSTOP = Constant('SIGSTOP',19)
SIGTSTP = Constant('SIGTSTP',20)
SIGTTIN = Constant('SIGTTIN',21)
SIGTTOU = Constant('SIGTTOU',22)
SIGURG = Constant('SIGURG',23)
SIGXCPU = Constant('SIGXCPU',24)
SIGXFSZ = Constant('SIGXFSZ',25)
SIGVTALRM = Constant('SIGVTALRM',26)
SIGPROF = Constant('SIGPROF',27)
SIGWINCH = Constant('SIGWINCH',28)
SIGIO = Constant('SIGIO',29)
SIGPWR = Constant('SIGPWR',30)
SIGSYS = Constant('SIGSYS',31)
SIGCLD = Constant('SIGCLD',17)
SIGPOLL = Constant('SIGPOLL',29)
SIGLOST = Constant('SIGLOST',30)
SIGRTMIN = Constant('SIGRTMIN',32)
SIGRTMAX = Constant('SIGRTMAX',(64-1))
SA_NOCLDSTOP = Constant('SA_NOCLDSTOP',0x00000001)
SA_NOCLDWAIT = Constant('SA_NOCLDWAIT',0x00000002)
SA_SIGINFO = Constant('SA_SIGINFO',0x00000004)
SA_THIRTYTWO = Constant('SA_THIRTYTWO',0x02000000)
SA_RESTORER = Constant('SA_RESTORER',0x04000000)
SA_ONSTACK = Constant('SA_ONSTACK',0x08000000)
SA_RESTART = Constant('SA_RESTART',0x10000000)
SA_INTERRUPT = Constant('SA_INTERRUPT',0x20000000)
SA_NODEFER = Constant('SA_NODEFER',0x40000000)
SA_RESETHAND = Constant('SA_RESETHAND',0x80000000)
SA_NOMASK = Constant('SA_NOMASK',0x40000000)
SA_ONESHOT = Constant('SA_ONESHOT',0x80000000)
SS_ONSTACK = Constant('SS_ONSTACK',1)
SS_DISABLE = Constant('SS_DISABLE',2)
MINSIGSTKSZ = Constant('MINSIGSTKSZ',2048)
SIGSTKSZ = Constant('SIGSTKSZ',8192)
SIG_BLOCK = Constant('SIG_BLOCK',0)
SIG_UNBLOCK = Constant('SIG_UNBLOCK',1)
SIG_SETMASK = Constant('SIG_SETMASK',2)
SI_MAX_SIZE = Constant('SI_MAX_SIZE',128)
SIGEV_SIGNAL = Constant('SIGEV_SIGNAL',0)
SIGEV_NONE = Constant('SIGEV_NONE',1)
SIGEV_THREAD = Constant('SIGEV_THREAD',2)
SIGEV_THREAD_ID = Constant('SIGEV_THREAD_ID',4)
SIGEV_MAX_SIZE = Constant('SIGEV_MAX_SIZE',64)
_SYS_TIME_H = Constant('_SYS_TIME_H',1)
ITIMER_REAL = Constant('ITIMER_REAL',0)
ITIMER_VIRTUAL = Constant('ITIMER_VIRTUAL',1)
ITIMER_PROF = Constant('ITIMER_PROF',2)
FD_SETSIZE = Constant('FD_SETSIZE',1024)
R_OK = Constant('R_OK',4)
W_OK = Constant('W_OK',2)
X_OK = Constant('X_OK',1)
F_OK = Constant('F_OK',0)
SEEK_SET = Constant('SEEK_SET',0)
SEEK_CUR = Constant('SEEK_CUR',1)
SEEK_END = Constant('SEEK_END',2)
STDIN_FILENO = Constant('STDIN_FILENO',0)
STDOUT_FILENO = Constant('STDOUT_FILENO',1)
STDERR_FILENO = Constant('STDERR_FILENO',2)
_CS_PATH = Constant('_CS_PATH',1)
_SC_CLK_TCK = Constant('_SC_CLK_TCK',1)
_SC_ARG_MAX = Constant('_SC_ARG_MAX',2)
_SC_NGROUPS_MAX = Constant('_SC_NGROUPS_MAX',3)
_SC_OPEN_MAX = Constant('_SC_OPEN_MAX',4)
_SC_PAGESIZE = Constant('_SC_PAGESIZE',5)
_SC_NPROCESSORS_ONLN = Constant('_SC_NPROCESSORS_ONLN',6)
_SC_NPROCESSORS_CONF = Constant('_SC_NPROCESSORS_CONF',6)
_SC_PHYS_PAGES = Constant('_SC_PHYS_PAGES',7)
_PC_PATH_MAX = Constant('_PC_PATH_MAX',1)
_PC_VDISABLE = Constant('_PC_VDISABLE',2)
L_cuserid = Constant('L_cuserid',17)
_POSIX_VERSION = Constant('_POSIX_VERSION',199506)
F_ULOCK = Constant('F_ULOCK',0)
F_LOCK = Constant('F_LOCK',1)
F_TLOCK = Constant('F_TLOCK',2)
F_TEST = Constant('F_TEST',3)
STAT64_HAS_BROKEN_ST_INO = Constant('STAT64_HAS_BROKEN_ST_INO',1)
S_IFMT = Constant('S_IFMT',0o0170000)
S_IFSOCK = Constant('S_IFSOCK',0o140000)
S_IFLNK = Constant('S_IFLNK',0o120000)
S_IFREG = Constant('S_IFREG',0o100000)
S_IFBLK = Constant('S_IFBLK',0o060000)
S_IFDIR = Constant('S_IFDIR',0o040000)
S_IFCHR = Constant('S_IFCHR',0o020000)
S_IFIFO = Constant('S_IFIFO',0o010000)
S_ISUID = Constant('S_ISUID',0o004000)
S_ISGID = Constant('S_ISGID',0o002000)
S_ISVTX = Constant('S_ISVTX',0o001000)
S_IRWXU = Constant('S_IRWXU',0o0700)
S_IRUSR = Constant('S_IRUSR',0o0400)
S_IWUSR = Constant('S_IWUSR',0o0200)
S_IXUSR = Constant('S_IXUSR',0o0100)
S_IRWXG = Constant('S_IRWXG',0o0070)
S_IRGRP = Constant('S_IRGRP',0o0040)
S_IWGRP = Constant('S_IWGRP',0o0020)
S_IXGRP = Constant('S_IXGRP',0o0010)
S_IRWXO = Constant('S_IRWXO',0o0007)
S_IROTH = Constant('S_IROTH',0o0004)
S_IWOTH = Constant('S_IWOTH',0o0002)
S_IXOTH = Constant('S_IXOTH',0o0001)
S_IREAD = Constant('S_IREAD',0o0400)
S_IWRITE = Constant('S_IWRITE',0o0200)
S_IEXEC = Constant('S_IEXEC',0o0100)
F_LINUX_SPECIFIC_BASE = Constant('F_LINUX_SPECIFIC_BASE',1024)
O_ACCMODE = Constant('O_ACCMODE',0o003)
O_RDONLY = Constant('O_RDONLY',0o0)
O_WRONLY = Constant('O_WRONLY',0o1)
O_RDWR = Constant('O_RDWR',0o2)
O_CREAT = Constant('O_CREAT',0o100)
O_EXCL = Constant('O_EXCL',0o200)
O_NOCTTY = Constant('O_NOCTTY',0o400)
O_TRUNC = Constant('O_TRUNC',0o1000)
O_APPEND = Constant('O_APPEND',0o2000)
O_NONBLOCK = Constant('O_NONBLOCK',0o4000)
O_NDELAY = Constant('O_NDELAY',0o4000)
O_SYNC = Constant('O_SYNC',0o10000)
FASYNC = Constant('FASYNC',0o20000)
O_DIRECTORY = Constant('O_DIRECTORY',0o40000)
O_NOFOLLOW = Constant('O_NOFOLLOW',0o100000)
O_DIRECT = Constant('O_DIRECT',0o200000)
O_LARGEFILE = Constant('O_LARGEFILE',0o400000)
O_NOATIME = Constant('O_NOATIME',0o1000000)
F_DUPFD = Constant('F_DUPFD',0)
F_GETFD = Constant('F_GETFD',1)
F_SETFD = Constant('F_SETFD',2)
F_GETFL = Constant('F_GETFL',3)
F_SETFL = Constant('F_SETFL',4)
F_GETLK = Constant('F_GETLK',5)
F_SETLK = Constant('F_SETLK',6)
F_SETLKW = Constant('F_SETLKW',7)
F_SETOWN = Constant('F_SETOWN',8)
F_GETOWN = Constant('F_GETOWN',9)
F_SETSIG = Constant('F_SETSIG',10)
F_GETSIG = Constant('F_GETSIG',11)
F_GETLK64 = Constant('F_GETLK64',12)
F_SETLK64 = Constant('F_SETLK64',13)
F_SETLKW64 = Constant('F_SETLKW64',14)
FD_CLOEXEC = Constant('FD_CLOEXEC',1)
F_RDLCK = Constant('F_RDLCK',0)
F_WRLCK = Constant('F_WRLCK',1)
F_UNLCK = Constant('F_UNLCK',2)
F_EXLCK = Constant('F_EXLCK',4)
F_SHLCK = Constant('F_SHLCK',8)
F_INPROGRESS = Constant('F_INPROGRESS',16)
LOCK_SH = Constant('LOCK_SH',1)
LOCK_EX = Constant('LOCK_EX',2)
LOCK_NB = Constant('LOCK_NB',4)
LOCK_UN = Constant('LOCK_UN',8)
LOCK_MAND = Constant('LOCK_MAND',32)
LOCK_READ = Constant('LOCK_READ',64)
LOCK_WRITE = Constant('LOCK_WRITE',128)
LOCK_RW = Constant('LOCK_RW',192)
O_ASYNC = Constant('O_ASYNC',0o20000)
MREMAP_MAYMOVE = Constant('MREMAP_MAYMOVE',1)
MREMAP_FIXED = Constant('MREMAP_FIXED',2)
PROT_READ = Constant('PROT_READ',0x1)
PROT_WRITE = Constant('PROT_WRITE',0x2)
PROT_EXEC = Constant('PROT_EXEC',0x4)
PROT_NONE = Constant('PROT_NONE',0x0)
MAP_SHARED = Constant('MAP_SHARED',0x01)
MAP_PRIVATE = Constant('MAP_PRIVATE',0x02)
MAP_FIXED = Constant('MAP_FIXED',0x10)
MAP_ANONYMOUS = Constant('MAP_ANONYMOUS',0x20)
MAP_GROWSDOWN = Constant('MAP_GROWSDOWN',0x0100)
MAP_DENYWRITE = Constant('MAP_DENYWRITE',0x0800)
MAP_EXECUTABLE = Constant('MAP_EXECUTABLE',0x1000)
MAP_LOCKED = Constant('MAP_LOCKED',0x2000)
MAP_NORESERVE = Constant('MAP_NORESERVE',0x4000)
MAP_POPULATE = Constant('MAP_POPULATE',0x8000)
MS_ASYNC = Constant('MS_ASYNC',1)
MS_INVALIDATE = Constant('MS_INVALIDATE',2)
MS_SYNC = Constant('MS_SYNC',4)
MCL_CURRENT = Constant('MCL_CURRENT',1)
MCL_FUTURE = Constant('MCL_FUTURE',2)
MADV_NORMAL = Constant('MADV_NORMAL',0x0)
MADV_RANDOM = Constant('MADV_RANDOM',0x1)
MADV_SEQUENTIAL = Constant('MADV_SEQUENTIAL',0x2)
MADV_WILLNEED = Constant('MADV_WILLNEED',0x3)
MADV_DONTNEED = Constant('MADV_DONTNEED',0x4)
MAP_ANON = Constant('MAP_ANON',0x20)
MAP_FILE = Constant('MAP_FILE',0)
SOL_SOCKET = Constant('SOL_SOCKET',1)
SO_DEBUG = Constant('SO_DEBUG',1)
SO_REUSEADDR = Constant('SO_REUSEADDR',2)
SO_TYPE = Constant('SO_TYPE',3)
SO_ERROR = Constant('SO_ERROR',4)
SO_DONTROUTE = Constant('SO_DONTROUTE',5)
SO_BROADCAST = Constant('SO_BROADCAST',6)
SO_SNDBUF = Constant('SO_SNDBUF',7)
SO_RCVBUF = Constant('SO_RCVBUF',8)
SO_KEEPALIVE = Constant('SO_KEEPALIVE',9)
SO_OOBINLINE = Constant('SO_OOBINLINE',10)
SO_NO_CHECK = Constant('SO_NO_CHECK',11)
SO_PRIORITY = Constant('SO_PRIORITY',12)
SO_LINGER = Constant('SO_LINGER',13)
SO_BSDCOMPAT = Constant('SO_BSDCOMPAT',14)
SO_PASSCRED = Constant('SO_PASSCRED',16)
SO_PEERCRED = Constant('SO_PEERCRED',17)
SO_RCVLOWAT = Constant('SO_RCVLOWAT',18)
SO_SNDLOWAT = Constant('SO_SNDLOWAT',19)
SO_RCVTIMEO = Constant('SO_RCVTIMEO',20)
SO_SNDTIMEO = Constant('SO_SNDTIMEO',21)
SO_ACCEPTCONN = Constant('SO_ACCEPTCONN',30)
SO_SNDBUFFORCE = Constant('SO_SNDBUFFORCE',32)
SO_RCVBUFFORCE = Constant('SO_RCVBUFFORCE',33)
SO_SECURITY_AUTHENTICATION = Constant('SO_SECURITY_AUTHENTICATION',22)
SO_SECURITY_ENCRYPTION_TRANSPORT = Constant('SO_SECURITY_ENCRYPTION_TRANSPORT',23)
SO_SECURITY_ENCRYPTION_NETWORK = Constant('SO_SECURITY_ENCRYPTION_NETWORK',24)
SO_BINDTODEVICE = Constant('SO_BINDTODEVICE',25)
SO_ATTACH_FILTER = Constant('SO_ATTACH_FILTER',26)
SO_DETACH_FILTER = Constant('SO_DETACH_FILTER',27)
SO_PEERNAME = Constant('SO_PEERNAME',28)
SO_TIMESTAMP = Constant('SO_TIMESTAMP',29)
SCM_TIMESTAMP = Constant('SCM_TIMESTAMP',29)
SOCK_STREAM = Constant('SOCK_STREAM',1)
SOCK_DGRAM = Constant('SOCK_DGRAM',2)
SOCK_RAW = Constant('SOCK_RAW',3)
SOCK_RDM = Constant('SOCK_RDM',4)
SOCK_SEQPACKET = Constant('SOCK_SEQPACKET',5)
SOCK_PACKET = Constant('SOCK_PACKET',10)
UIO_FASTIOV = Constant('UIO_FASTIOV',8)
UIO_MAXIOV = Constant('UIO_MAXIOV',1024)
SCM_RIGHTS = Constant('SCM_RIGHTS',0x01)
SCM_CREDENTIALS = Constant('SCM_CREDENTIALS',0x02)
SCM_CONNECT = Constant('SCM_CONNECT',0x03)
AF_UNSPEC = Constant('AF_UNSPEC',0)
AF_UNIX = Constant('AF_UNIX',1)
AF_LOCAL = Constant('AF_LOCAL',1)
AF_INET = Constant('AF_INET',2)
AF_AX25 = Constant('AF_AX25',3)
AF_IPX = Constant('AF_IPX',4)
AF_APPLETALK = Constant('AF_APPLETALK',5)
AF_NETROM = Constant('AF_NETROM',6)
AF_BRIDGE = Constant('AF_BRIDGE',7)
AF_ATMPVC = Constant('AF_ATMPVC',8)
AF_X25 = Constant('AF_X25',9)
AF_INET6 = Constant('AF_INET6',10)
AF_ROSE = Constant('AF_ROSE',11)
AF_DECnet = Constant('AF_DECnet',12)
AF_NETBEUI = Constant('AF_NETBEUI',13)
AF_SECURITY = Constant('AF_SECURITY',14)
AF_KEY = Constant('AF_KEY',15)
AF_NETLINK = Constant('AF_NETLINK',16)
AF_ROUTE = Constant('AF_ROUTE',16)
AF_PACKET = Constant('AF_PACKET',17)
AF_ASH = Constant('AF_ASH',18)
AF_ECONET = Constant('AF_ECONET',19)
AF_ATMSVC = Constant('AF_ATMSVC',20)
AF_SNA = Constant('AF_SNA',22)
AF_IRDA = Constant('AF_IRDA',23)
AF_PPPOX = Constant('AF_PPPOX',24)
AF_WANPIPE = Constant('AF_WANPIPE',25)
AF_MAX = Constant('AF_MAX',32)
PF_UNSPEC = Constant('PF_UNSPEC',0)
PF_UNIX = Constant('PF_UNIX',1)
PF_LOCAL = Constant('PF_LOCAL',1)
PF_INET = Constant('PF_INET',2)
PF_AX25 = Constant('PF_AX25',3)
PF_IPX = Constant('PF_IPX',4)
PF_APPLETALK = Constant('PF_APPLETALK',5)
PF_NETROM = Constant('PF_NETROM',6)
PF_BRIDGE = Constant('PF_BRIDGE',7)
PF_ATMPVC = Constant('PF_ATMPVC',8)
PF_X25 = Constant('PF_X25',9)
PF_INET6 = Constant('PF_INET6',10)
PF_ROSE = Constant('PF_ROSE',11)
PF_DECnet = Constant('PF_DECnet',12)
PF_NETBEUI = Constant('PF_NETBEUI',13)
PF_SECURITY = Constant('PF_SECURITY',14)
PF_KEY = Constant('PF_KEY',15)
PF_NETLINK = Constant('PF_NETLINK',16)
PF_ROUTE = Constant('PF_ROUTE',16)
PF_PACKET = Constant('PF_PACKET',17)
PF_ASH = Constant('PF_ASH',18)
PF_ECONET = Constant('PF_ECONET',19)
PF_ATMSVC = Constant('PF_ATMSVC',20)
PF_SNA = Constant('PF_SNA',22)
PF_IRDA = Constant('PF_IRDA',23)
PF_PPPOX = Constant('PF_PPPOX',24)
PF_WANPIPE = Constant('PF_WANPIPE',25)
PF_MAX = Constant('PF_MAX',32)
SOMAXCONN = Constant('SOMAXCONN',128)
MSG_OOB = Constant('MSG_OOB',1)
MSG_PEEK = Constant('MSG_PEEK',2)
MSG_DONTROUTE = Constant('MSG_DONTROUTE',4)
MSG_TRYHARD = Constant('MSG_TRYHARD',4)
MSG_CTRUNC = Constant('MSG_CTRUNC',8)
MSG_PROBE = Constant('MSG_PROBE',0x10)
MSG_TRUNC = Constant('MSG_TRUNC',0x20)
MSG_DONTWAIT = Constant('MSG_DONTWAIT',0x40)
MSG_EOR = Constant('MSG_EOR',0x80)
MSG_WAITALL = Constant('MSG_WAITALL',0x100)
MSG_FIN = Constant('MSG_FIN',0x200)
MSG_EOF = Constant('MSG_EOF',0x200)
MSG_SYN = Constant('MSG_SYN',0x400)
MSG_CONFIRM = Constant('MSG_CONFIRM',0x800)
MSG_RST = Constant('MSG_RST',0x1000)
MSG_ERRQUEUE = Constant('MSG_ERRQUEUE',0x2000)
MSG_NOSIGNAL = Constant('MSG_NOSIGNAL',0x4000)
MSG_MORE = Constant('MSG_MORE',0x8000)
SOL_IP = Constant('SOL_IP',0)
SOL_TCP = Constant('SOL_TCP',6)
SOL_UDP = Constant('SOL_UDP',17)
SOL_IPV6 = Constant('SOL_IPV6',41)
SOL_ICMPV6 = Constant('SOL_ICMPV6',58)
SOL_RAW = Constant('SOL_RAW',255)
SOL_IPX = Constant('SOL_IPX',256)
SOL_AX25 = Constant('SOL_AX25',257)
SOL_ATALK = Constant('SOL_ATALK',258)
SOL_NETROM = Constant('SOL_NETROM',259)
SOL_ROSE = Constant('SOL_ROSE',260)
SOL_DECNET = Constant('SOL_DECNET',261)
SOL_X25 = Constant('SOL_X25',262)
SOL_PACKET = Constant('SOL_PACKET',263)
SOL_ATM = Constant('SOL_ATM',264)
SOL_AAL = Constant('SOL_AAL',265)
SOL_IRDA = Constant('SOL_IRDA',266)
IPX_TYPE = Constant('IPX_TYPE',1)
SHUT_RD = Constant('SHUT_RD',0)
SHUT_WR = Constant('SHUT_WR',1)
SHUT_RDWR = Constant('SHUT_RDWR',2)
NI_NOFQDN = Constant('NI_NOFQDN',1)
NI_NUMERICHOST = Constant('NI_NUMERICHOST',2)
NI_NAMEREQD = Constant('NI_NAMEREQD',4)
NI_NUMERICSERV = Constant('NI_NUMERICSERV',8)
NI_DGRAM = Constant('NI_DGRAM',16)
EAI_FAMILY = Constant('EAI_FAMILY',-1)
EAI_SOCKTYPE = Constant('EAI_SOCKTYPE',-2)
EAI_BADFLAGS = Constant('EAI_BADFLAGS',-3)
EAI_NONAME = Constant('EAI_NONAME',-4)
EAI_SERVICE = Constant('EAI_SERVICE',-5)
EAI_ADDRFAMILY = Constant('EAI_ADDRFAMILY',-6)
EAI_NODATA = Constant('EAI_NODATA',-7)
EAI_MEMORY = Constant('EAI_MEMORY',-8)
EAI_FAIL = Constant('EAI_FAIL',-9)
EAI_AGAIN = Constant('EAI_AGAIN',-10)
EAI_SYSTEM = Constant('EAI_SYSTEM',-11)
AI_NUMERICHOST = Constant('AI_NUMERICHOST',1)
AI_CANONNAME = Constant('AI_CANONNAME',2)
AI_PASSIVE = Constant('AI_PASSIVE',4)
SIOCADDRT = Constant('SIOCADDRT',0x890B)
SIOCDELRT = Constant('SIOCDELRT',0x890C)
SIOCRTMSG = Constant('SIOCRTMSG',0x890D)
SIOCGIFNAME = Constant('SIOCGIFNAME',0x8910)
SIOCSIFLINK = Constant('SIOCSIFLINK',0x8911)
SIOCGIFCONF = Constant('SIOCGIFCONF',0x8912)
SIOCGIFFLAGS = Constant('SIOCGIFFLAGS',0x8913)
SIOCSIFFLAGS = Constant('SIOCSIFFLAGS',0x8914)
SIOCGIFADDR = Constant('SIOCGIFADDR',0x8915)
SIOCSIFADDR = Constant('SIOCSIFADDR',0x8916)
SIOCGIFDSTADDR = Constant('SIOCGIFDSTADDR',0x8917)
SIOCSIFDSTADDR = Constant('SIOCSIFDSTADDR',0x8918)
SIOCGIFBRDADDR = Constant('SIOCGIFBRDADDR',0x8919)
SIOCSIFBRDADDR = Constant('SIOCSIFBRDADDR',0x891a)
SIOCGIFNETMASK = Constant('SIOCGIFNETMASK',0x891b)
SIOCSIFNETMASK = Constant('SIOCSIFNETMASK',0x891c)
SIOCGIFMETRIC = Constant('SIOCGIFMETRIC',0x891d)
SIOCSIFMETRIC = Constant('SIOCSIFMETRIC',0x891e)
SIOCGIFMEM = Constant('SIOCGIFMEM',0x891f)
SIOCSIFMEM = Constant('SIOCSIFMEM',0x8920)
SIOCGIFMTU = Constant('SIOCGIFMTU',0x8921)
SIOCSIFMTU = Constant('SIOCSIFMTU',0x8922)
SIOCSIFNAME = Constant('SIOCSIFNAME',0x8923)
SIOCSIFHWADDR = Constant('SIOCSIFHWADDR',0x8924)
SIOCGIFENCAP = Constant('SIOCGIFENCAP',0x8925)
SIOCSIFENCAP = Constant('SIOCSIFENCAP',0x8926)
SIOCGIFHWADDR = Constant('SIOCGIFHWADDR',0x8927)
SIOCGIFSLAVE = Constant('SIOCGIFSLAVE',0x8929)
SIOCSIFSLAVE = Constant('SIOCSIFSLAVE',0x8930)
SIOCADDMULTI = Constant('SIOCADDMULTI',0x8931)
SIOCDELMULTI = Constant('SIOCDELMULTI',0x8932)
SIOCGIFINDEX = Constant('SIOCGIFINDEX',0x8933)
SIOGIFINDEX = Constant('SIOGIFINDEX',0x8933)
SIOCSIFPFLAGS = Constant('SIOCSIFPFLAGS',0x8934)
SIOCGIFPFLAGS = Constant('SIOCGIFPFLAGS',0x8935)
SIOCDIFADDR = Constant('SIOCDIFADDR',0x8936)
SIOCSIFHWBROADCAST = Constant('SIOCSIFHWBROADCAST',0x8937)
SIOCGIFCOUNT = Constant('SIOCGIFCOUNT',0x8938)
SIOCGIFBR = Constant('SIOCGIFBR',0x8940)
SIOCSIFBR = Constant('SIOCSIFBR',0x8941)
SIOCGIFTXQLEN = Constant('SIOCGIFTXQLEN',0x8942)
SIOCSIFTXQLEN = Constant('SIOCSIFTXQLEN',0x8943)
SIOCGIFDIVERT = Constant('SIOCGIFDIVERT',0x8944)
SIOCSIFDIVERT = Constant('SIOCSIFDIVERT',0x8945)
SIOCETHTOOL = Constant('SIOCETHTOOL',0x8946)
SIOCDARP = Constant('SIOCDARP',0x8953)
SIOCGARP = Constant('SIOCGARP',0x8954)
SIOCSARP = Constant('SIOCSARP',0x8955)
SIOCDRARP = Constant('SIOCDRARP',0x8960)
SIOCGRARP = Constant('SIOCGRARP',0x8961)
SIOCSRARP = Constant('SIOCSRARP',0x8962)
SIOCGIFMAP = Constant('SIOCGIFMAP',0x8970)
SIOCSIFMAP = Constant('SIOCSIFMAP',0x8971)
SIOCADDDLCI = Constant('SIOCADDDLCI',0x8980)
SIOCDELDLCI = Constant('SIOCDELDLCI',0x8981)
SIOCDEVPRIVATE = Constant('SIOCDEVPRIVATE',0x89F0)
PTRACE_TRACEME = Constant('PTRACE_TRACEME',0)
PTRACE_PEEKTEXT = Constant('PTRACE_PEEKTEXT',1)
PTRACE_PEEKDATA = Constant('PTRACE_PEEKDATA',2)
PTRACE_PEEKUSR = Constant('PTRACE_PEEKUSR',3)
PTRACE_PEEKUSER = Constant('PTRACE_PEEKUSER',3)
PTRACE_POKETEXT = Constant('PTRACE_POKETEXT',4)
PTRACE_POKEDATA = Constant('PTRACE_POKEDATA',5)
PTRACE_POKEUSR = Constant('PTRACE_POKEUSR',6)
PTRACE_POKEUSER = Constant('PTRACE_POKEUSER',6)
PTRACE_CONT = Constant('PTRACE_CONT',7)
PTRACE_KILL = Constant('PTRACE_KILL',8)
PTRACE_SINGLESTEP = Constant('PTRACE_SINGLESTEP',9)
PTRACE_ATTACH = Constant('PTRACE_ATTACH',0x10)
PTRACE_DETACH = Constant('PTRACE_DETACH',0x11)
PTRACE_SYSCALL = Constant('PTRACE_SYSCALL',24)
PTRACE_GETEVENTMSG = Constant('PTRACE_GETEVENTMSG',0x4201)
PTRACE_GETSIGINFO = Constant('PTRACE_GETSIGINFO',0x4202)
PTRACE_SETSIGINFO = Constant('PTRACE_SETSIGINFO',0x4203)
PTRACE_O_TRACESYSGOOD = Constant('PTRACE_O_TRACESYSGOOD',0x00000001)
PTRACE_O_TRACEFORK = Constant('PTRACE_O_TRACEFORK',0x00000002)
PTRACE_O_TRACEVFORK = Constant('PTRACE_O_TRACEVFORK',0x00000004)
PTRACE_O_TRACECLONE = Constant('PTRACE_O_TRACECLONE',0x00000008)
PTRACE_O_TRACEEXEC = Constant('PTRACE_O_TRACEEXEC',0x00000010)
PTRACE_O_TRACEVFORKDONE = Constant('PTRACE_O_TRACEVFORKDONE',0x00000020)
PTRACE_O_TRACEEXIT = Constant('PTRACE_O_TRACEEXIT',0x00000040)
PTRACE_O_MASK = Constant('PTRACE_O_MASK',0x0000007f)
PTRACE_EVENT_FORK = Constant('PTRACE_EVENT_FORK',1)
PTRACE_EVENT_VFORK = Constant('PTRACE_EVENT_VFORK',2)
PTRACE_EVENT_CLONE = Constant('PTRACE_EVENT_CLONE',3)
PTRACE_EVENT_EXEC = Constant('PTRACE_EVENT_EXEC',4)
PTRACE_EVENT_VFORK_DONE = Constant('PTRACE_EVENT_VFORK_DONE',5)
PTRACE_EVENT_EXIT = Constant('PTRACE_EVENT_EXIT',6)
PT_TRACE_ME = Constant('PT_TRACE_ME',0)
PT_READ_I = Constant('PT_READ_I',1)
PT_READ_D = Constant('PT_READ_D',2)
PT_READ_U = Constant('PT_READ_U',3)
PT_WRITE_I = Constant('PT_WRITE_I',4)
PT_WRITE_D = Constant('PT_WRITE_D',5)
PT_WRITE_U = Constant('PT_WRITE_U',6)
PT_CONTINUE = Constant('PT_CONTINUE',7)
PT_KILL = Constant('PT_KILL',8)
PT_STEP = Constant('PT_STEP',9)
PT_ATTACH = Constant('PT_ATTACH',0x10)
PT_DETACH = Constant('PT_DETACH',0x11)
USR26_MODE = Constant('USR26_MODE',0x00)
FIQ26_MODE = Constant('FIQ26_MODE',0x01)
IRQ26_MODE = Constant('IRQ26_MODE',0x02)
SVC26_MODE = Constant('SVC26_MODE',0x03)
USR_MODE = Constant('USR_MODE',0x10)
FIQ_MODE = Constant('FIQ_MODE',0x11)
IRQ_MODE = Constant('IRQ_MODE',0x12)
SVC_MODE = Constant('SVC_MODE',0x13)
ABT_MODE = Constant('ABT_MODE',0x17)
UND_MODE = Constant('UND_MODE',0x1b)
SYSTEM_MODE = Constant('SYSTEM_MODE',0x1f)
MODE_MASK = Constant('MODE_MASK',0x1f)
T_BIT = Constant('T_BIT',0x20)
F_BIT = Constant('F_BIT',0x40)
I_BIT = Constant('I_BIT',0x80)
CC_V_BIT = Constant('CC_V_BIT',(1 << 28))
CC_C_BIT = Constant('CC_C_BIT',(1 << 29))
CC_Z_BIT = Constant('CC_Z_BIT',(1 << 30))
CC_N_BIT = Constant('CC_N_BIT',(1 << 31))
PCMASK = Constant('PCMASK',0)
SYS_accept = Constant('SYS_accept',(0+285))
SYS_access = Constant('SYS_access',(0+ 33))
SYS_acct = Constant('SYS_acct',(0+ 51))
SYS_add_key = Constant('SYS_add_key',(0+309))
SYS_adjtimex = Constant('SYS_adjtimex',(0+124))
SYS_alarm = Constant('SYS_alarm',(0+ 27))
SYS_arm_fadvise64_64 = Constant('SYS_arm_fadvise64_64',(0+270))
SYS_arm_sync_file_range = Constant('SYS_arm_sync_file_range',(0+341))
SYS_bdflush = Constant('SYS_bdflush',(0+134))
SYS_bind = Constant('SYS_bind',(0+282))
SYS_brk = Constant('SYS_brk',(0+ 45))
SYS_capget = Constant('SYS_capget',(0+184))
SYS_capset = Constant('SYS_capset',(0+185))
SYS_chdir = Constant('SYS_chdir',(0+ 12))
SYS_chmod = Constant('SYS_chmod',(0+ 15))
SYS_chown = Constant('SYS_chown',(0+182))
SYS_chown32 = Constant('SYS_chown32',(0+212))
SYS_chroot = Constant('SYS_chroot',(0+ 61))
SYS_clock_getres = Constant('SYS_clock_getres',(0+264))
SYS_clock_gettime = Constant('SYS_clock_gettime',(0+263))
SYS_clock_nanosleep = Constant('SYS_clock_nanosleep',(0+265))
SYS_clock_settime = Constant('SYS_clock_settime',(0+262))
SYS_clone = Constant('SYS_clone',(0+120))
SYS_close = Constant('SYS_close',(0+  6))
SYS_connect = Constant('SYS_connect',(0+283))
SYS_creat = Constant('SYS_creat',(0+  8))
SYS_delete_module = Constant('SYS_delete_module',(0+129))
SYS_dup = Constant('SYS_dup',(0+ 41))
SYS_dup2 = Constant('SYS_dup2',(0+ 63))
SYS_epoll_create = Constant('SYS_epoll_create',(0+250))
SYS_epoll_ctl = Constant('SYS_epoll_ctl',(0+251))
SYS_epoll_wait = Constant('SYS_epoll_wait',(0+252))
SYS_eventfd = Constant('SYS_eventfd',(0+351))
SYS_execve = Constant('SYS_execve',(0+ 11))
SYS_exit = Constant('SYS_exit',(0+  1))
SYS_exit_group = Constant('SYS_exit_group',(0+248))
SYS_faccessat = Constant('SYS_faccessat',(0+334))
SYS_fallocate = Constant('SYS_fallocate',(0+352))
SYS_fchdir = Constant('SYS_fchdir',(0+133))
SYS_fchmod = Constant('SYS_fchmod',(0+ 94))
SYS_fchmodat = Constant('SYS_fchmodat',(0+333))
SYS_fchown = Constant('SYS_fchown',(0+ 95))
SYS_fchown32 = Constant('SYS_fchown32',(0+207))
SYS_fchownat = Constant('SYS_fchownat',(0+325))
SYS_fcntl = Constant('SYS_fcntl',(0+ 55))
SYS_fcntl64 = Constant('SYS_fcntl64',(0+221))
SYS_fdatasync = Constant('SYS_fdatasync',(0+148))
SYS_fgetxattr = Constant('SYS_fgetxattr',(0+231))
SYS_flistxattr = Constant('SYS_flistxattr',(0+234))
SYS_flock = Constant('SYS_flock',(0+143))
SYS_fork = Constant('SYS_fork',(0+  2))
SYS_fremovexattr = Constant('SYS_fremovexattr',(0+237))
SYS_fsetxattr = Constant('SYS_fsetxattr',(0+228))
SYS_fstat = Constant('SYS_fstat',(0+108))
SYS_fstat64 = Constant('SYS_fstat64',(0+197))
SYS_fstatat64 = Constant('SYS_fstatat64',(0+327))
SYS_fstatfs = Constant('SYS_fstatfs',(0+100))
SYS_fstatfs64 = Constant('SYS_fstatfs64',(0+267))
SYS_fsync = Constant('SYS_fsync',(0+118))
SYS_ftruncate = Constant('SYS_ftruncate',(0+ 93))
SYS_ftruncate64 = Constant('SYS_ftruncate64',(0+194))
SYS_futex = Constant('SYS_futex',(0+240))
SYS_futimesat = Constant('SYS_futimesat',(0+326))
SYS_getcpu = Constant('SYS_getcpu',(0+345))
SYS_getcwd = Constant('SYS_getcwd',(0+183))
SYS_getdents = Constant('SYS_getdents',(0+141))
SYS_getdents64 = Constant('SYS_getdents64',(0+217))
SYS_getegid = Constant('SYS_getegid',(0+ 50))
SYS_getegid32 = Constant('SYS_getegid32',(0+202))
SYS_geteuid = Constant('SYS_geteuid',(0+ 49))
SYS_geteuid32 = Constant('SYS_geteuid32',(0+201))
SYS_getgid = Constant('SYS_getgid',(0+ 47))
SYS_getgid32 = Constant('SYS_getgid32',(0+200))
SYS_getgroups = Constant('SYS_getgroups',(0+ 80))
SYS_getgroups32 = Constant('SYS_getgroups32',(0+205))
SYS_getitimer = Constant('SYS_getitimer',(0+105))
SYS_get_mempolicy = Constant('SYS_get_mempolicy',(0+320))
SYS_getpeername = Constant('SYS_getpeername',(0+287))
SYS_getpgid = Constant('SYS_getpgid',(0+132))
SYS_getpgrp = Constant('SYS_getpgrp',(0+ 65))
SYS_getpid = Constant('SYS_getpid',(0+ 20))
SYS_getppid = Constant('SYS_getppid',(0+ 64))
SYS_getpriority = Constant('SYS_getpriority',(0+ 96))
SYS_getresgid = Constant('SYS_getresgid',(0+171))
SYS_getresgid32 = Constant('SYS_getresgid32',(0+211))
SYS_getresuid = Constant('SYS_getresuid',(0+165))
SYS_getresuid32 = Constant('SYS_getresuid32',(0+209))
SYS_getrlimit = Constant('SYS_getrlimit',(0+ 76))
SYS_get_robust_list = Constant('SYS_get_robust_list',(0+339))
SYS_getrusage = Constant('SYS_getrusage',(0+ 77))
SYS_getsid = Constant('SYS_getsid',(0+147))
SYS_getsockname = Constant('SYS_getsockname',(0+286))
SYS_getsockopt = Constant('SYS_getsockopt',(0+295))
SYS_gettid = Constant('SYS_gettid',(0+224))
SYS_gettimeofday = Constant('SYS_gettimeofday',(0+ 78))
SYS_getuid = Constant('SYS_getuid',(0+ 24))
SYS_getuid32 = Constant('SYS_getuid32',(0+199))
SYS_getxattr = Constant('SYS_getxattr',(0+229))
SYS_init_module = Constant('SYS_init_module',(0+128))
SYS_inotify_add_watch = Constant('SYS_inotify_add_watch',(0+317))
SYS_inotify_init = Constant('SYS_inotify_init',(0+316))
SYS_inotify_rm_watch = Constant('SYS_inotify_rm_watch',(0+318))
SYS_io_cancel = Constant('SYS_io_cancel',(0+247))
SYS_ioctl = Constant('SYS_ioctl',(0+ 54))
SYS_io_destroy = Constant('SYS_io_destroy',(0+244))
SYS_io_getevents = Constant('SYS_io_getevents',(0+245))
SYS_ioprio_get = Constant('SYS_ioprio_get',(0+315))
SYS_ioprio_set = Constant('SYS_ioprio_set',(0+314))
SYS_io_setup = Constant('SYS_io_setup',(0+243))
SYS_io_submit = Constant('SYS_io_submit',(0+246))
SYS_ipc = Constant('SYS_ipc',(0+117))
SYS_kexec_load = Constant('SYS_kexec_load',(0+347))
SYS_keyctl = Constant('SYS_keyctl',(0+311))
SYS_kill = Constant('SYS_kill',(0+ 37))
SYS_lchown = Constant('SYS_lchown',(0+ 16))
SYS_lchown32 = Constant('SYS_lchown32',(0+198))
SYS_lgetxattr = Constant('SYS_lgetxattr',(0+230))
SYS_link = Constant('SYS_link',(0+  9))
SYS_linkat = Constant('SYS_linkat',(0+330))
SYS_listen = Constant('SYS_listen',(0+284))
SYS_listxattr = Constant('SYS_listxattr',(0+232))
SYS_llistxattr = Constant('SYS_llistxattr',(0+233))
SYS__llseek = Constant('SYS__llseek',(0+140))
SYS_lookup_dcookie = Constant('SYS_lookup_dcookie',(0+249))
SYS_lremovexattr = Constant('SYS_lremovexattr',(0+236))
SYS_lseek = Constant('SYS_lseek',(0+ 19))
SYS_lsetxattr = Constant('SYS_lsetxattr',(0+227))
SYS_lstat = Constant('SYS_lstat',(0+107))
SYS_lstat64 = Constant('SYS_lstat64',(0+196))
SYS_madvise = Constant('SYS_madvise',(0+220))
SYS_mbind = Constant('SYS_mbind',(0+319))
SYS_mincore = Constant('SYS_mincore',(0+219))
SYS_mkdir = Constant('SYS_mkdir',(0+ 39))
SYS_mkdirat = Constant('SYS_mkdirat',(0+323))
SYS_mknod = Constant('SYS_mknod',(0+ 14))
SYS_mknodat = Constant('SYS_mknodat',(0+324))
SYS_mlock = Constant('SYS_mlock',(0+150))
SYS_mlockall = Constant('SYS_mlockall',(0+152))
SYS_mmap = Constant('SYS_mmap',(0+ 90))
SYS_mmap2 = Constant('SYS_mmap2',(0+192))
SYS_mount = Constant('SYS_mount',(0+ 21))
SYS_move_pages = Constant('SYS_move_pages',(0+344))
SYS_mprotect = Constant('SYS_mprotect',(0+125))
SYS_mq_getsetattr = Constant('SYS_mq_getsetattr',(0+279))
SYS_mq_notify = Constant('SYS_mq_notify',(0+278))
SYS_mq_open = Constant('SYS_mq_open',(0+274))
SYS_mq_timedreceive = Constant('SYS_mq_timedreceive',(0+277))
SYS_mq_timedsend = Constant('SYS_mq_timedsend',(0+276))
SYS_mq_unlink = Constant('SYS_mq_unlink',(0+275))
SYS_mremap = Constant('SYS_mremap',(0+163))
SYS_msgctl = Constant('SYS_msgctl',(0+304))
SYS_msgget = Constant('SYS_msgget',(0+303))
SYS_msgrcv = Constant('SYS_msgrcv',(0+302))
SYS_msgsnd = Constant('SYS_msgsnd',(0+301))
SYS_msync = Constant('SYS_msync',(0+144))
SYS_munlock = Constant('SYS_munlock',(0+151))
SYS_munlockall = Constant('SYS_munlockall',(0+153))
SYS_munmap = Constant('SYS_munmap',(0+ 91))
SYS_nanosleep = Constant('SYS_nanosleep',(0+162))
SYS__newselect = Constant('SYS__newselect',(0+142))
SYS_nfsservctl = Constant('SYS_nfsservctl',(0+169))
SYS_nice = Constant('SYS_nice',(0+ 34))
SYS_OABI_SYSCALL_BASE = Constant('SYS_OABI_SYSCALL_BASE',0x900000)
SYS_open = Constant('SYS_open',(0+  5))
SYS_openat = Constant('SYS_openat',(0+322))
SYS_pause = Constant('SYS_pause',(0+ 29))
SYS_pciconfig_iobase = Constant('SYS_pciconfig_iobase',(0+271))
SYS_pciconfig_read = Constant('SYS_pciconfig_read',(0+272))
SYS_pciconfig_write = Constant('SYS_pciconfig_write',(0+273))
SYS_personality = Constant('SYS_personality',(0+136))
SYS_pipe = Constant('SYS_pipe',(0+ 42))
SYS_pivot_root = Constant('SYS_pivot_root',(0+218))
SYS_poll = Constant('SYS_poll',(0+168))
SYS_prctl = Constant('SYS_prctl',(0+172))
SYS_pread64 = Constant('SYS_pread64',(0+180))
SYS_ptrace = Constant('SYS_ptrace',(0+ 26))
SYS_pwrite64 = Constant('SYS_pwrite64',(0+181))
SYS_quotactl = Constant('SYS_quotactl',(0+131))
SYS_read = Constant('SYS_read',(0+  3))
SYS_readahead = Constant('SYS_readahead',(0+225))
SYS_readdir = Constant('SYS_readdir',(0+ 89))
SYS_readlink = Constant('SYS_readlink',(0+ 85))
SYS_readlinkat = Constant('SYS_readlinkat',(0+332))
SYS_readv = Constant('SYS_readv',(0+145))
SYS_reboot = Constant('SYS_reboot',(0+ 88))
SYS_recv = Constant('SYS_recv',(0+291))
SYS_recvfrom = Constant('SYS_recvfrom',(0+292))
SYS_recvmsg = Constant('SYS_recvmsg',(0+297))
SYS_remap_file_pages = Constant('SYS_remap_file_pages',(0+253))
SYS_removexattr = Constant('SYS_removexattr',(0+235))
SYS_rename = Constant('SYS_rename',(0+ 38))
SYS_renameat = Constant('SYS_renameat',(0+329))
SYS_request_key = Constant('SYS_request_key',(0+310))
SYS_restart_syscall = Constant('SYS_restart_syscall',(0+  0))
SYS_rmdir = Constant('SYS_rmdir',(0+ 40))
SYS_rt_sigaction = Constant('SYS_rt_sigaction',(0+174))
SYS_rt_sigpending = Constant('SYS_rt_sigpending',(0+176))
SYS_rt_sigprocmask = Constant('SYS_rt_sigprocmask',(0+175))
SYS_rt_sigqueueinfo = Constant('SYS_rt_sigqueueinfo',(0+178))
SYS_rt_sigreturn = Constant('SYS_rt_sigreturn',(0+173))
SYS_rt_sigsuspend = Constant('SYS_rt_sigsuspend',(0+179))
SYS_rt_sigtimedwait = Constant('SYS_rt_sigtimedwait',(0+177))
SYS_sched_getaffinity = Constant('SYS_sched_getaffinity',(0+242))
SYS_sched_getparam = Constant('SYS_sched_getparam',(0+155))
SYS_sched_get_priority_max = Constant('SYS_sched_get_priority_max',(0+159))
SYS_sched_get_priority_min = Constant('SYS_sched_get_priority_min',(0+160))
SYS_sched_getscheduler = Constant('SYS_sched_getscheduler',(0+157))
SYS_sched_rr_get_interval = Constant('SYS_sched_rr_get_interval',(0+161))
SYS_sched_setaffinity = Constant('SYS_sched_setaffinity',(0+241))
SYS_sched_setparam = Constant('SYS_sched_setparam',(0+154))
SYS_sched_setscheduler = Constant('SYS_sched_setscheduler',(0+156))
SYS_sched_yield = Constant('SYS_sched_yield',(0+158))
SYS_select = Constant('SYS_select',(0+ 82))
SYS_semctl = Constant('SYS_semctl',(0+300))
SYS_semget = Constant('SYS_semget',(0+299))
SYS_semop = Constant('SYS_semop',(0+298))
SYS_semtimedop = Constant('SYS_semtimedop',(0+312))
SYS_send = Constant('SYS_send',(0+289))
SYS_sendfile = Constant('SYS_sendfile',(0+187))
SYS_sendfile64 = Constant('SYS_sendfile64',(0+239))
SYS_sendmsg = Constant('SYS_sendmsg',(0+296))
SYS_sendto = Constant('SYS_sendto',(0+290))
SYS_setdomainname = Constant('SYS_setdomainname',(0+121))
SYS_setfsgid = Constant('SYS_setfsgid',(0+139))
SYS_setfsgid32 = Constant('SYS_setfsgid32',(0+216))
SYS_setfsuid = Constant('SYS_setfsuid',(0+138))
SYS_setfsuid32 = Constant('SYS_setfsuid32',(0+215))
SYS_setgid = Constant('SYS_setgid',(0+ 46))
SYS_setgid32 = Constant('SYS_setgid32',(0+214))
SYS_setgroups = Constant('SYS_setgroups',(0+ 81))
SYS_setgroups32 = Constant('SYS_setgroups32',(0+206))
SYS_sethostname = Constant('SYS_sethostname',(0+ 74))
SYS_setitimer = Constant('SYS_setitimer',(0+104))
SYS_set_mempolicy = Constant('SYS_set_mempolicy',(0+321))
SYS_setpgid = Constant('SYS_setpgid',(0+ 57))
SYS_setpriority = Constant('SYS_setpriority',(0+ 97))
SYS_setregid = Constant('SYS_setregid',(0+ 71))
SYS_setregid32 = Constant('SYS_setregid32',(0+204))
SYS_setresgid = Constant('SYS_setresgid',(0+170))
SYS_setresgid32 = Constant('SYS_setresgid32',(0+210))
SYS_setresuid = Constant('SYS_setresuid',(0+164))
SYS_setresuid32 = Constant('SYS_setresuid32',(0+208))
SYS_setreuid = Constant('SYS_setreuid',(0+ 70))
SYS_setreuid32 = Constant('SYS_setreuid32',(0+203))
SYS_setrlimit = Constant('SYS_setrlimit',(0+ 75))
SYS_set_robust_list = Constant('SYS_set_robust_list',(0+338))
SYS_setsid = Constant('SYS_setsid',(0+ 66))
SYS_setsockopt = Constant('SYS_setsockopt',(0+294))
SYS_set_tid_address = Constant('SYS_set_tid_address',(0+256))
SYS_settimeofday = Constant('SYS_settimeofday',(0+ 79))
SYS_setuid = Constant('SYS_setuid',(0+ 23))
SYS_setuid32 = Constant('SYS_setuid32',(0+213))
SYS_setxattr = Constant('SYS_setxattr',(0+226))
SYS_shmat = Constant('SYS_shmat',(0+305))
SYS_shmctl = Constant('SYS_shmctl',(0+308))
SYS_shmdt = Constant('SYS_shmdt',(0+306))
SYS_shmget = Constant('SYS_shmget',(0+307))
SYS_shutdown = Constant('SYS_shutdown',(0+293))
SYS_sigaction = Constant('SYS_sigaction',(0+ 67))
SYS_sigaltstack = Constant('SYS_sigaltstack',(0+186))
SYS_signalfd = Constant('SYS_signalfd',(0+349))
SYS_sigpending = Constant('SYS_sigpending',(0+ 73))
SYS_sigprocmask = Constant('SYS_sigprocmask',(0+126))
SYS_sigreturn = Constant('SYS_sigreturn',(0+119))
SYS_sigsuspend = Constant('SYS_sigsuspend',(0+ 72))
SYS_socket = Constant('SYS_socket',(0+281))
SYS_socketcall = Constant('SYS_socketcall',(0+102))
SYS_socketpair = Constant('SYS_socketpair',(0+288))
SYS_splice = Constant('SYS_splice',(0+340))
SYS_stat = Constant('SYS_stat',(0+106))
SYS_stat64 = Constant('SYS_stat64',(0+195))
SYS_statfs = Constant('SYS_statfs',(0+ 99))
SYS_statfs64 = Constant('SYS_statfs64',(0+266))
SYS_stime = Constant('SYS_stime',(0+ 25))
SYS_swapoff = Constant('SYS_swapoff',(0+115))
SYS_swapon = Constant('SYS_swapon',(0+ 87))
SYS_symlink = Constant('SYS_symlink',(0+ 83))
SYS_symlinkat = Constant('SYS_symlinkat',(0+331))
SYS_sync = Constant('SYS_sync',(0+ 36))
SYS_syscall = Constant('SYS_syscall',(0+113))
SYS_SYSCALL_BASE = Constant('SYS_SYSCALL_BASE',0)
SYS__sysctl = Constant('SYS__sysctl',(0+149))
SYS_sysfs = Constant('SYS_sysfs',(0+135))
SYS_sysinfo = Constant('SYS_sysinfo',(0+116))
SYS_syslog = Constant('SYS_syslog',(0+103))
SYS_tee = Constant('SYS_tee',(0+342))
SYS_tgkill = Constant('SYS_tgkill',(0+268))
SYS_time = Constant('SYS_time',(0+ 13))
SYS_timer_create = Constant('SYS_timer_create',(0+257))
SYS_timer_delete = Constant('SYS_timer_delete',(0+261))
SYS_timerfd = Constant('SYS_timerfd',(0+350))
SYS_timerfd_gettime = Constant('SYS_timerfd_gettime',(0+354))
SYS_timerfd_settime = Constant('SYS_timerfd_settime',(0+353))
SYS_timer_getoverrun = Constant('SYS_timer_getoverrun',(0+260))
SYS_timer_gettime = Constant('SYS_timer_gettime',(0+259))
SYS_timer_settime = Constant('SYS_timer_settime',(0+258))
SYS_times = Constant('SYS_times',(0+ 43))
SYS_tkill = Constant('SYS_tkill',(0+238))
SYS_truncate = Constant('SYS_truncate',(0+ 92))
SYS_truncate64 = Constant('SYS_truncate64',(0+193))
SYS_ugetrlimit = Constant('SYS_ugetrlimit',(0+191))
SYS_umask = Constant('SYS_umask',(0+ 60))
SYS_umount = Constant('SYS_umount',(0+ 22))
SYS_umount2 = Constant('SYS_umount2',(0+ 52))
SYS_uname = Constant('SYS_uname',(0+122))
SYS_unlink = Constant('SYS_unlink',(0+ 10))
SYS_unlinkat = Constant('SYS_unlinkat',(0+328))
SYS_unshare = Constant('SYS_unshare',(0+337))
SYS_uselib = Constant('SYS_uselib',(0+ 86))
SYS_ustat = Constant('SYS_ustat',(0+ 62))
SYS_utime = Constant('SYS_utime',(0+ 30))
SYS_utimensat = Constant('SYS_utimensat',(0+348))
SYS_utimes = Constant('SYS_utimes',(0+269))
SYS_vfork = Constant('SYS_vfork',(0+190))
SYS_vhangup = Constant('SYS_vhangup',(0+111))
SYS_vmsplice = Constant('SYS_vmsplice',(0+343))
SYS_vserver = Constant('SYS_vserver',(0+313))
SYS_wait4 = Constant('SYS_wait4',(0+114))
SYS_waitid = Constant('SYS_waitid',(0+280))
SYS_write = Constant('SYS_write',(0+  4))
SYS_writev = Constant('SYS_writev',(0+146))
